=== added directory 'docs/administration'
=== added file 'docs/administration/authentication.rst'
--- docs/administration/authentication.rst	1970-01-01 00:00:00 +0000
+++ docs/administration/authentication.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,29 @@
+Authentication
+==============
+
+Authentication is any process by which you verify that someone is who they
+claim they are. [1]_  Drizzle authentication is handled by plugins; there
+are no grant or privilege tables.
+
+One or more authentication plugin must be loaded, else no connections can
+be made to Drizzle.  On most systems, the :doc:`/plugins/auth_all/index`
+plugin is loaded by default which, as its name suggests, allows all
+connections regardless of username or password.  (Some distributions enable
+the :doc:`/plugins/auth_file/index` plugin by default instead).
+
+`Choosing an authentication plugin, configuring it, and disabling all other
+authentication plugins should be one of your first administrative tasks.`
+
+The following authentication plugins are included with Drizzle:
+
+* :doc:`/plugins/auth_all/index`
+* :doc:`/plugins/auth_file/index`
+* :doc:`/plugins/auth_http/index`
+* :doc:`/plugins/auth_ldap/index`
+* :doc:`/plugins/auth_pam/index`
+
+-------------------------------------------------------------------------------
+
+.. rubric:: Footnotes
+
+.. [1] `Authentication, Authorization, and Access Control <http://httpd.apache.org/docs/1.3/howto/auth.html>`_

=== added file 'docs/administration/authorization.rst'
--- docs/administration/authorization.rst	1970-01-01 00:00:00 +0000
+++ docs/administration/authorization.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,12 @@
+Authorization
+=============
+
+Authorization is finding out if the person, once identified, is permitted to
+have the resource. [1]_  Drizzle authorization is handled by plugins; there
+are no grant or privilege tables.
+
+-------------------------------------------------------------------------------
+
+.. rubric:: Footnotes
+
+.. [1] `Authentication, Authorization, and Access Control <http://httpd.apache.org/docs/1.3/howto/auth.html>`_

=== added file 'docs/administration/index.rst'
--- docs/administration/index.rst	1970-01-01 00:00:00 +0000
+++ docs/administration/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,8 @@
+Administration
+==============
+
+.. toctree::
+
+   authentication
+   authorization
+   storage_engines

=== added file 'docs/administration/storage_engines.rst'
--- docs/administration/storage_engines.rst	1970-01-01 00:00:00 +0000
+++ docs/administration/storage_engines.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,12 @@
+Storage Engines
+===============
+
+Drizzle's micro-kernel has been designed to allow for data to be stored and
+provided for by different "engines". Engines differ in many ways, but the
+three primary types are, temporary only, transactional, and non-transaction.
+
+Drizzle runs by default with a transactional engine for both regular and
+temporary tables. You can override this behavior by specifying a different
+engine when creating a table.
+
+Some engines (for example MyISAM) may only support creating temporary tables.

=== removed file 'docs/authentication.rst'
--- docs/authentication.rst	2011-03-08 03:47:42 +0000
+++ docs/authentication.rst	1970-01-01 00:00:00 +0000
@@ -1,12 +0,0 @@
-AUTHENTICATION
-==============
-
-For Drizzle, authentication is handled by plugins.
-
-Authentication is no longer based on the host/user and
-schema/table/column model that was used in the MyISAM-based mysql.user
-table.
-
-The pluggable model capitalizes on existing systems such as PAM, LDAP
-via PAM and HTTP authentication.
-

=== removed file 'docs/file.rst'
--- docs/file.rst	2010-10-27 21:19:18 +0000
+++ docs/file.rst	1970-01-01 00:00:00 +0000
@@ -1,2 +0,0 @@
-File
-===========

=== modified file 'docs/functions/mathematical.rst'
--- docs/functions/mathematical.rst	2011-02-23 14:17:23 +0000
+++ docs/functions/mathematical.rst	2011-08-13 20:41:38 +0000
@@ -17,68 +17,3 @@
 ``!!``      factorial            ``!! 5``      120
 ``@``       absolute value       ``@ -5.0``    5
 ========    ==================   ============  ======
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-

=== modified file 'docs/functions/overview.rst'
--- docs/functions/overview.rst	2011-03-17 16:33:45 +0000
+++ docs/functions/overview.rst	2011-08-13 20:41:38 +0000
@@ -12,5 +12,6 @@
    aggregatefunctions
    control_flow
    string
+   utility
    ../dynamic
   

=== modified file 'docs/functions/string.rst'
--- docs/functions/string.rst	2011-02-23 00:00:04 +0000
+++ docs/functions/string.rst	2011-08-13 20:41:38 +0000
@@ -1,7 +1,7 @@
 String Functions and Operators
 ===============================
 
-**(See tables with each function listed with a brief description below.)**
+.. seealso:: :ref:`string-functions-summary`
 
 .. toctree::
    :maxdepth: 2
@@ -13,12 +13,13 @@
    string/position
    string/other
 
-
-List of string operators and descriptions by type of function:
-
+.. _string-functions-summary:
+
+Summary of Functions
+--------------------
 
 Comparative and regular functions
----------------------------------
+^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
 ===================     ====================================================================================================
 Operator                  Description
@@ -33,7 +34,7 @@
 
 
 Conversion and translation functions
-------------------------------------
+^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 ===================     ====================================================================================================
 Operator                  Description
 ===================     ====================================================================================================
@@ -50,7 +51,7 @@
 
 
 Length and size functions
--------------------------
+^^^^^^^^^^^^^^^^^^^^^^^^^
 ===================     ====================================================================================================
 Operator                  Description
 ===================     ====================================================================================================
@@ -62,7 +63,7 @@
 
 
 Formatting and modification functions
--------------------------------------
+^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 ===================     ====================================================================================================
 Operator                  Description
 ===================     ====================================================================================================
@@ -74,7 +75,7 @@
 
 
 Position functions
--------------------
+^^^^^^^^^^^^^^^^^^
 
 ===================     ====================================================================================================
 Operator                  Description
@@ -90,7 +91,7 @@
 
 
 Other string functions
-----------------------
+^^^^^^^^^^^^^^^^^^^^^^
 
 ===================     ====================================================================================================
 Operator                  Description

=== modified file 'docs/functions/string/comparative.rst'
--- docs/functions/string/comparative.rst	2011-03-01 00:48:42 +0000
+++ docs/functions/string/comparative.rst	2011-08-13 20:41:38 +0000
@@ -1,6 +1,8 @@
 Comparative Functions
 =====================
 
+.. _like-function:
+
 LIKE 	        
 ----
 
@@ -24,6 +26,14 @@
 	WHERE title LIKE 'DIRECTOR%'
 	ORDER BY field, title;
 
+.. _regex-function:
+
+REGEX
+-----
+
+Undocumented.
+
+.. _regexp-function:
 
 REGEXP
 ------
@@ -54,8 +64,9 @@
 
 	SELECT 'abcabc' REGEXP 'ABC', 'abcabc' REGEXP BINARY 'ABC';
 
+.. _strcmp-function:
 
-STRCMP()
---------
+STRCMP
+------
 
 The purpose of STRCMP is also to compare two strings. This function returns 0 if two strings are the same, -1 if the first argument is smaller than the second according to the current sort order, and 1 otherwise.

=== modified file 'docs/functions/string/conversion.rst'
--- docs/functions/string/conversion.rst	2011-02-23 13:08:09 +0000
+++ docs/functions/string/conversion.rst	2011-08-13 20:41:38 +0000
@@ -1,9 +1,12 @@
 Conversion Functions
 ====================
 
+.. _ascii-function:
+
 ASCII
 -----
- The ASCII(str) function returns the numeric value of the leftmost character of the string ’str’. It returns NULL if str is NULL. It works for 8-bit characters.
+
+The ASCII(str) function returns the numeric value of the leftmost character of the string ’str’. It returns NULL if str is NULL. It works for 8-bit characters.
 
 For example:
 
@@ -19,10 +22,12 @@
 
 Returns 100
 
+.. _bin-function:
 
 BIN
 ---
- The BIN string function returns a string value that represents the binary value of N, where N is a longlong(BIGINT) number. This function is equivalent to CONV(N, 10 , 0). If the function return the null then N is null. 
+
+The BIN string function returns a string value that represents the binary value of N, where N is a longlong(BIGINT) number. This function is equivalent to CONV(N, 10 , 0). If the function return the null then N is null. 
 
 Syntax:
 
@@ -37,9 +42,12 @@
 Returns: '1100'
 
 
+.. _char-function:
+
 CHAR
 ----
- SQL CHAR function is the opposite of the ASCII function. It converts an integer in range 0-255 into a ASCII character. It returns a string (the character), given the integer value. This function skips NULL values.    
+
+SQL CHAR function is the opposite of the ASCII function. It converts an integer in range 0-255 into a ASCII character. It returns a string (the character), given the integer value. This function skips NULL values.    
 For example:
 
 .. code-block:: mysql
@@ -48,8 +56,10 @@
 
 Returns "A" 
 
-HEX()
------
+.. _hex-function:
+
+HEX
+---
 
 This string function returns the hexadecimal (base-16) representation of a string or decicmal argument. Each character in the string argument is converted to two hexadecimal digits. If the argument is numeric, HEX() returns a hexadecimal string representation of the value as a BIGINT number.
 
@@ -71,9 +81,10 @@
 
 (To better understand this output, you can use an :doc:`../../resources/ascii_chart` that includes both Hexadecimal and character values.)
 
+.. _unhex-function:
 
-UNHEX()
--------
+UNHEX
+-----
 
 UNHEX converts each pair of hexadecimal digits to a character. For a string argument, UNHEX() is the inverse operation of HEX(str).
 
@@ -105,18 +116,30 @@
 
 Returns NULL
 
-
-LOWER() 	          
-Return the argument in lowercase
-
-
-LCASE() 	          
-Synonym for LOWER()
-
-
-UCASE()
+.. _lower-function:
+
+LOWER
+-----
+
+Return the argument in lowercase.
+
+.. _lcase-function:
+
+LCASE
+-----
+
+Synonym for LOWER().
+
+.. _ucase-function:
+
+UCASE
+-----
+
 Synonym for UPPER()
 
-
-UPPER() 	          
-Convert to uppercase
+.. _upper-function:
+
+UPPER
+-----
+
+Convert to uppercase.

=== modified file 'docs/functions/string/length.rst'
--- docs/functions/string/length.rst	2011-02-23 13:08:09 +0000
+++ docs/functions/string/length.rst	2011-08-13 20:41:38 +0000
@@ -1,6 +1,8 @@
 Length and Size Functions
 =========================
 
+.. _bit-lenght-function:
+
 BIT_LENGTH
 ----------
 The BIT_LENGTH(str) function return the String str length in bits. Here are the some example of the BIT_LENGTH(str) function: 
@@ -12,6 +14,8 @@
 
 Returns 8
 
+.. _char-length-function:
+
 CHAR_LENGTH
 -----------
 The CHAR_LENGTH(str) function returns string length measured in characters. 
@@ -22,9 +26,17 @@
 
 This function is same as CHAR_LENGTH().
 
-
-LENGTH()
---------
+.. _character-length-function:
+
+CHARACTER_LENGTH
+----------------
+
+Synonym for CHAR_LENGTH.
+
+.. _length-function:
+
+LENGTH
+------
 
 The LENGTH function returns the length of the string argument in bytes. A multi-byte character counts as multiple bytes. This means that for a string containing a three-byte character, LENGTH() returns 3, whereas CHAR_LENGTH() returns 1. For example:
 
@@ -36,7 +48,9 @@
 
 The is because the Euro sign is encoded as 0xE282AC in UTF-8 and thereby occupies 3 bytes.
 
-OCTET_LENGTH()
----------------
-
-A synonym for LENGTH()
+.. _octet-length-function:
+
+OCTET_LENGTH
+-------------
+
+A synonym for LENGTH().

=== modified file 'docs/functions/string/modification.rst'
--- docs/functions/string/modification.rst	2011-02-23 13:08:09 +0000
+++ docs/functions/string/modification.rst	2011-08-13 20:41:38 +0000
@@ -1,6 +1,8 @@
 String Modification Functions
 =============================
 
+.. _concat-function:
+
 CONCAT
 ------
 
@@ -35,6 +37,8 @@
 
 Returns: '14.8'
 
+.. _concat-ws-function:
+
 CONCAT_WS
 ---------
 CONCAT WS (With Separator) [1]_ allows you to specify that the first argument is treated as a separator for the rest of the arguments. This argument is added between the strings to be concatenated.
@@ -57,9 +61,10 @@
 
 Returns: 'First name, Last Name'
 
+.. _trim-function:
 
-TRIM()
-------
+TRIM
+----
 
 The TRIM function remove specified prefixes or suffixes from a string (typically leading and trailing spaces), and returns the resulting string. If none of the specifiers BOTH, LEADING, or TRAILING is given, BOTH is assumed.
 
@@ -69,14 +74,17 @@
 
 [remstr] is optional (if it's not specified, spaces are removed).
 
-LTRIM()
--------
+.. _ltrim-function:
+
+LTRIM
+-----
 
 This version of the TRIM function removes leading spaces from the beginning of a string.
 
+.. _rtrim-function:
 
-RTRIM()
--------
+RTRIM
+-----
 
 This version of the TRIM function removes trailing spaces from the end of a function. 
 

=== modified file 'docs/functions/string/other.rst'
--- docs/functions/string/other.rst	2011-02-23 13:08:09 +0000
+++ docs/functions/string/other.rst	2011-08-13 20:41:38 +0000
@@ -1,69 +1,95 @@
 Other String Functions
 ======================
 
-LOAD_FILE()
------------
-
-Load the named file
-
-ELT()
------
-
-Return string at index number
-
-EXPORT_SET()
+.. _coercibility-function:
+
+COERCIBILITY
 ------------
 
+Gets coercibility for an expression.
+
+.. _elt-function:
+
+ELT
+---
+
+Return string at index number.
+
+.. _export-set-function:
+
+EXPORT_SET
+----------
+
 Return a string
 
-FORMAT()
---------
-
-Return a number formatted to specified number of decimal places
-
-LOAD_FILE()
------------
-
-Load the named file
-
-LPAD()
--------
-
-Return the string argument, left-padded with the specified string
-
-MAKE_SET()
-----------
-
-Return a set of comma-separated strings that have the corresponding bit in bits set
-
-MATCH()
--------
-
-Perform full-text search
-
-MID()
------
-
-Return a substring starting from the specified position
-
-ORD()
------
-
-Return character code for leftmost character of the argument
-
-QUOTE()
--------
-
-Escape the argument for use in an SQL statement
-
-REPEAT()
---------
-
-Repeat a string the specified number of times
-
-REPLACE()
+.. _format-function:
+
+FORMAT
+------
+
+Return a number formatted to specified number of decimal places.
+
+.. _load-file-function:
+
+LOAD_FILE
 ---------
 
+Load the named file.
+
+.. _lpad-function:
+
+LPAD
+----
+
+Return the string argument, left-padded with the specified string.
+
+.. _make-set-function:
+
+MAKE_SET
+--------
+
+Return a set of comma-separated strings that have the corresponding bit in bits set.
+
+.. _match-function:
+
+MATCH
+-----
+
+Perform full-text search.
+
+.. _mid-function:
+
+MID
+---
+
+Return a substring starting from the specified position.
+
+.. _ord-function:
+
+ORD
+---
+
+Return character code for leftmost character of the argument.
+
+.. _quote-function:
+
+QUOTE
+-----
+
+Escape the argument for use in an SQL statement.
+
+.. _repeat-function:
+
+REPEAT
+------
+
+Repeat a string the specified number of times.
+
+.. _replace-function:
+
+REPLACE
+-------
+
 The REPLACE() function returns a string with all occurrences of the 'from_str' replaced by 'to_str'. REPLACE is case-sensitive when searching for 'from_str'.
 
 Syntax:
@@ -78,8 +104,10 @@
 
 Returns: vvv.google.com
 
-REVERSE()
----------
+.. _reverse-function:
+
+REVERSE
+-------
 
 This function returns a string argument with the characters in reverse order.
 
@@ -89,24 +117,38 @@
 
 Returns: dcba
 
-RIGHT()
--------
+.. _right-function:
+
+RIGHT
+-----
 
 Return the specified rightmost number of characters
 
-RPAD()
-------
+.. _rpad-function:
+
+RPAD
+----
 
 Append string the specified number of times
 
-SOUNDEX()
----------
+.. _soundex-function:
+
+SOUNDEX
+-------
 
 Return a soundex string
 
-
-SUBSTRING()
------------
+.. _substr-function:
+
+SUBSTR
+------
+
+Synonym for SUBSTRING().
+
+.. _substring-function:
+
+SUBSTRING
+---------
 
 Returns the substring as specified
 
@@ -132,4 +174,10 @@
 	FROM Students
 	LIMIT 10;
 
-
+.. _substring-index-function:
+
+
+SUBSTRING_INDEX
+---------------
+
+Return a substring from a string before the specified number of occurrences of the delimiter.

=== modified file 'docs/functions/string/position.rst'
--- docs/functions/string/position.rst	2011-02-23 13:08:09 +0000
+++ docs/functions/string/position.rst	2011-08-13 20:41:38 +0000
@@ -1,6 +1,8 @@
 Position Functions
 ==================
 
+.. _field-function:
+
 FIELD
 -----
 
@@ -26,11 +28,15 @@
 
 Returns 0
 
+.. _find-in-set-function:
+
 FIND_IN_SET
 -----------
 
 Return the index position of the first argument within the second argument
 
+.. _instr-function:
+
 INSTR
 -----
 
@@ -43,11 +49,15 @@
 	SELECT INSTR('burger', 'salad');
         	-> 0
 
+.. _left-function:
+
 LEFT
 ----
 
 Return the leftmost number of characters as specified
 
+.. _insert-function:
+
 INSERT
 ------
 
@@ -70,14 +80,16 @@
 	SELECT INSERT('Aquatic', 3, 100, 'This');
         	-> 'AqThis'
 
+.. _locate-function:
 
 LOCATE
 ------
 
 Return the position of the first occurrence of substring.
 
+.. _position-function:
+
 POSITION
 --------
 
 A synonym for LOCATE()
-

=== added file 'docs/functions/utility.rst'
--- docs/functions/utility.rst	1970-01-01 00:00:00 +0000
+++ docs/functions/utility.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,44 @@
+Utility Functions
+=================
+
+.. _benchmark-function:
+
+BENCHMARK
+---------
+
+The BENCHMARK function measures time for repeated calls to a function.
+
+.. _compress-function:
+
+COMPRESS
+--------
+
+Compress the argument.
+
+.. _connection-id-function:
+
+CONNECTION_ID
+-------------
+
+Returns the session's connection ID.
+
+.. _crc32-function:
+
+CRC32
+-----
+
+Return the CRC32 checksum of the argument.
+
+.. _uncompress-function:
+
+UNCOMPRESS
+----------
+
+Uncompress a compressed argument.
+
+.. _uncompressed-length-function:
+
+UNCOMPRESSED_LENGTH
+-------------------
+
+Returns the uncompressed lenght of the argument.

=== modified file 'docs/index.rst'
--- docs/index.rst	2011-06-10 00:21:57 +0000
+++ docs/index.rst	2011-08-13 20:41:38 +0000
@@ -24,8 +24,8 @@
  * Reliable, ACID transactional
 
 
-Introduction:
--------------
+Introduction
+------------
 .. toctree::
    :maxdepth: 2
    
@@ -37,8 +37,8 @@
    versioning
    mysql_differences
 
-Compiling and Installing:
--------------------------
+Compiling and Installing
+------------------------
 .. toctree::
    :maxdepth: 2
 
@@ -47,8 +47,8 @@
    installing/ubuntu
    installing/redhat
 
-Contributing:
--------------
+Contributing
+------------
 .. toctree::
    :maxdepth: 2
 
@@ -56,8 +56,8 @@
    contributing/code
    contributing/documentation
 
-SQL Language:
--------------
+SQL Language
+------------
 .. toctree::
    :maxdepth: 2
 
@@ -76,39 +76,37 @@
    administrative
    resources/index
 
-Replication:
-------------
+Replication
+-----------
 .. toctree::
    :maxdepth: 2
 
    replication
 
-Configuration:
---------------
+Configuration
+-------------
 .. toctree::
    :maxdepth: 2
 
    configuration
    options
 
-Administrative:
----------------
+Administration
+--------------
 .. toctree::
    :maxdepth: 2
 
-   logging
-   authentication
-   storage_engines
+   administration/index
 
-Plugins:
-^^^^^^^^
+Plugins
+-------
 .. toctree::
    :maxdepth: 2
 
    plugins/list
 
-Clients:
---------
+Clients
+-------
 .. toctree::
    :maxdepth: 2
 
@@ -116,8 +114,8 @@
    clients/drizzledump.rst
    clients/errors.rst
 
-libdrizzle:
------------
+libdrizzle
+----------
 .. toctree::
    :maxdepth: 2
 
@@ -125,8 +123,8 @@
    libdrizzle/developer.rst
    protocol
 
-Testing:
---------
+Testing
+-------
 .. toctree::
    :maxdepth: 2
  

=== removed file 'docs/logging.rst'
--- docs/logging.rst	2011-01-14 05:15:57 +0000
+++ docs/logging.rst	1970-01-01 00:00:00 +0000
@@ -1,10 +0,0 @@
-Logging
-=======
-
-Drizzle provides a number of logging plugins.
-
-.. toctree::
-   :maxdepth: 2
-
-   syslog
-   file

=== modified file 'docs/mysql_differences.rst'
--- docs/mysql_differences.rst	2011-03-14 20:37:50 +0000
+++ docs/mysql_differences.rst	2011-08-13 20:41:38 +0000
@@ -118,15 +118,15 @@
 
 This allows developers to easily know if the query is portable or not.
 
-Authentication, Authorization and Access
-----------------------------------------
-
-Authentication lies in Drizzle plugins. Currently there are PAM and HTTP AUTH plugins for authentication.
-Through the PAM plugin, you can use any PAM module (such as LDAP).
-
-For more information, see our :doc:`authentication` doc.
-
-Command line clients
+Authentication, Authorization, and Access
+-----------------------------------------
+
+There are no grant or privilege tables.  Drizzle authentication, authorization,
+and access are provided by plugins.
+
+.. seealso:: :doc:`/administration/authentication`
+
+Command Line Clients
 --------------------
 
 We've stopped the confusion: -p means port and -P means password.

=== removed file 'docs/storage_engines.rst'
--- docs/storage_engines.rst	2011-02-16 03:27:34 +0000
+++ docs/storage_engines.rst	1970-01-01 00:00:00 +0000
@@ -1,12 +0,0 @@
-Storage Engines
-===============
-
-Drizzle's micro-kernel has been designed to allow for data to be stored and
-provided for by different "engines". Engines differ in many ways, but the
-three primary types are, temporary only, transactional, and non-transaction.
-
-Drizzle runs by default with a transactional engine for both regular and
-temporary tables. You can override this behavior by specifying a different
-engine when creating a table.
-
-Some engines (for example MyISAM) may only support creating temporary tables.

=== removed file 'docs/syslog.rst'
--- docs/syslog.rst	2010-10-27 21:19:18 +0000
+++ docs/syslog.rst	1970-01-01 00:00:00 +0000
@@ -1,2 +0,0 @@
-Unix Syslog
-===========

=== added directory 'plugin/ascii/docs'
=== added file 'plugin/ascii/docs/index.rst'
--- plugin/ascii/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/ascii/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,45 @@
+ASCII Function
+==============
+
+The ``ascii`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`ascii-function`
+
+.. _ascii_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=ascii
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _ascii_authors:
+
+Authors
+-------
+
+Devananda van der Veen
+
+.. _ascii_version:
+
+Version
+-------
+
+This documentation applies to **ascii 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='ascii'
+
+Changelog
+---------
+
+v1.0
+^^^^
+* First release.

=== modified file 'plugin/ascii/plugin.ini'
--- plugin/ascii/plugin.ini	2009-11-29 17:17:21 +0000
+++ plugin/ascii/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,4 +1,3 @@
 [plugin]
-title=UDF Plugin for ASCII 
-description=UDF Plugin for returning ASCII value of a character
+title=ASCII Function
 load_by_default=yes

=== added directory 'plugin/auth_all/docs'
=== added file 'plugin/auth_all/docs/index.rst'
--- plugin/auth_all/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/auth_all/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,76 @@
+Allow All Authentication
+========================
+
+.. warning:: :program:`auth_all` is a security risk!  Do not use this plugin with production servers!
+
+:program:`auth_all` is an authentication plugin that allows *all* connections
+regardless of username or password, so it does not actually authenticate and
+it does not provide any security.  This plugin is mostly used for testing.
+
+.. seealso:: :doc:`/administration/authentication`
+
+.. _auth_all_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`auth_all_configuration` and
+:ref:`auth_all_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=auth_all
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _auth_all_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. option:: --auth-all.allow_anonymous 
+
+   :Default: false
+   :Variable:
+
+   Allow anonymous access.
+
+.. _auth_all_variables:
+
+Variables
+---------
+
+This plugin does not register any variables.
+
+Authors
+-------
+
+Brian Aker
+
+.. _auth_all_version:
+
+Version
+-------
+
+This documentation applies to **auth_all 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='auth_all'
+
+Changelog
+---------
+
+v1.0
+^^^^
+* First release.

=== modified file 'plugin/auth_all/plugin.ini'
--- plugin/auth_all/plugin.ini	2011-03-03 18:57:27 +0000
+++ plugin/auth_all/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,8 +1,5 @@
 [plugin]
 title=Allow All Authentication
-description=Default authentication module.
 load_by_default=yes
 static=yes
-sources= 
-  auth_all.cc
-headers=
+sources=auth_all.cc

=== added directory 'plugin/auth_file/docs'
=== added file 'plugin/auth_file/docs/index.rst'
--- plugin/auth_file/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/auth_file/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,116 @@
+File-based Authentication
+=========================
+
+.. warning:: :program:`auth_file` is a security risk!  Do not use this plugin with production servers!
+
+:program:`auth_file` is an authentication plugin that authenticates connections
+using a list of ``username:password`` entries in a plain text file.
+
+.. note:: Unload the :doc:`/plugins/auth_all/index` plugin before using this plugin.
+.. seealso:: :doc:`/administration/authentication` 
+
+.. _auth_file_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=auth_file
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`auth_file_configuration` and :ref:`auth_file_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _auth_file_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. option:: --auth-file.users ARG
+
+   :Default: :file:`BASEDIR/etc/drizzle.users`
+   :Variable: :ref:`auth_file_users <auth_file_users>`
+
+   File to load for usernames and passwords.
+
+.. _auth_file_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _auth_file_users:
+
+* ``auth_file_users``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--auth-file.users`
+
+   File to load for usernames and passwords.
+
+.. _auth_file_examples:
+
+Examples
+--------
+
+First, create a :file:`users` file with one ``user:pass`` entry per line, like::
+
+   user1:password1
+   user2:password2
+
+Then start :program:`drizzled` like::
+
+   sbin/drizzled --plugin-remove=auth_all \  
+                 --plugin-add=auth_file   \
+                 --auth-file.users=/path/to/my/users
+
+Test that it works::
+
+   $ drizzle
+   ERROR 1045 (28000): Access denied for user 'daniel' (using password: NO)
+
+   $ drizzle --user=user1
+   ERROR 1045 (28000): Access denied for user 'user1' (using password: NO)
+
+   $ drizzle --user=user1 --password=password1
+   Welcome to the Drizzle client..  Commands end with ; or \g.
+   ...
+
+.. _auth_file_authors:
+
+Authors
+-------
+
+Eric Day
+
+.. _auth_file_version:
+
+Version
+-------
+
+This documentation applies to **auth_file 0.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='auth_file'
+
+Changelog
+---------
+
+v0.1
+^^^^
+* First release.
+

=== added directory 'plugin/auth_http/docs'
=== added file 'plugin/auth_http/docs/index.rst'
--- plugin/auth_http/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/auth_http/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,97 @@
+HTTP Authentication
+===================
+
+:program:`auth_http` is an authentication plugin that authenticates connections
+using web-based HTTP authentication through a URL.  A web server is required
+to provide authentication.  For example, see Apache's documentation
+for `Authentication, Authorization and Access Control <http://httpd.apache.org/docs/2.0/howto/auth.html>`_.
+Currently, SSL connections are not supported.
+
+.. note:: Unload the :doc:`/plugins/auth_all/index` plugin before using this plugin.
+.. seealso:: :doc:`/administration/authentication` 
+
+.. _auth_http_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=auth_http
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`auth_http_configuration` and :ref:`auth_http_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _auth_http_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. option:: --auth-http.url ARG
+
+   :Default: 
+   :Variable: :ref:`auth_http_url <auth_http_url>`
+   :Required: **This option must be specified**
+
+   URL for http authentication (required).  If this plugin is loaded, then
+   this option must be specified, else :program:`drizzled` will not start.
+
+.. _auth_http_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _auth_http_url:
+
+* ``auth_http_url``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--auth-http.url`
+
+   URL for HTTP authentication.
+
+.. _auth_http_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _auth_http_authors:
+
+Authors
+-------
+
+Mark Atwood
+
+.. _auth_http_version:
+
+Version
+-------
+
+This documentation applies to **auth_http 0.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='auth_http'
+
+Chanagelog
+----------
+
+v0.1
+^^^^
+* First release.

=== modified file 'plugin/auth_http/plugin.ini'
--- plugin/auth_http/plugin.ini	2009-11-29 17:17:21 +0000
+++ plugin/auth_http/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=HTTP Authentication Plugin
+title=HTTP Authentication
 description=HTTP based authentications
 sources=auth_http.cc
 build_conditional="${ac_cv_libcurl}" = "yes"

=== added directory 'plugin/auth_ldap/docs'
=== added file 'plugin/auth_ldap/docs/index.rst'
--- plugin/auth_ldap/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/auth_ldap/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,195 @@
+LDAP Authentication
+===================
+
+:program:`auth_ldap` is an authentication plugin that authenticates connections
+using an :abbr:`LDAP (Lightweight Directory Access Protocol)` server.  An
+LDAP server is required to provide authentication.
+
+.. note:: Unload the :doc:`/plugins/auth_all/index` plugin before using this plugin.
+.. seealso:: :doc:`/administration/authentication` 
+
+.. _auth_ldap_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=auth_ldap
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`auth_ldap_configuration` and :ref:`auth_ldap_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _auth_ldap_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. option:: --auth-ldap.base-dn ARG
+
+   :Default: 
+   :Variable: :ref:`auth_ldap_base_dn <auth_ldap_base_dn>`
+
+   DN to use when searching.
+
+.. option:: --auth-ldap.bind-db ARG
+
+   :Default: 
+   :Variable: :ref:`auth_ldap_bind_dn <auth_ldap_bind_dn>`
+
+   DN to use when binding to the LDAP server.
+
+.. option:: --auth-ldap.bind-password ARG
+
+   :Default: 
+   :Variable: :ref:`auth_ldap_bind_password <auth_ldap_bind_password>`
+
+   Password to use when binding the DN.
+
+.. option:: --auth-ldap.cache-timeout ARG
+
+   :Default: ``0``
+   :Variable: :ref:`auth_ldap_cache_timeout <auth_ldap_cache_timeout>`
+
+   How often to empty the users cache, 0 to disable.
+
+.. option:: --auth-ldap.mysql-password-attribute ARG
+
+   :Default: ``mysqlUserPassword``
+   :Variable: :ref:`auth_ldap_mysql_password_attribute <auth_ldap_mysql_password_attribute>`
+
+   Attribute in LDAP with MySQL hashed password.
+
+.. option:: --auth-ldap.password-attribute ARG
+
+   :Default: ``userPassword``
+   :Variable: :ref:`auth_ldap_password_attribute <auth_ldap_password_attribute>`
+
+   Attribute in LDAP with plain text password.
+
+.. option:: --auth-ldap.uri ARG
+
+   :Default: ``ldap://127.0.0.1/``
+   :Variable: :ref:`auth_ldap_uri <auth_ldap_uri>`
+
+   URI of the LDAP server to contact.
+
+.. _auth_ldap_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _auth_ldap_base_dn:
+
+* ``auth_ldap_base_dn``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--auth-ldap.base-dn`
+
+   DN to use when searching.
+
+.. _auth_ldap_bind_dn:
+
+* ``auth_ldap_bind_dn``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--auth-ldap.bind-db`
+
+   DN to use when binding to the LDAP server.
+
+.. _auth_ldap_bind_password:
+
+* ``auth_ldap_bind_password``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--auth-ldap.bind-password`
+
+   Password to use when binding the DN.
+
+.. _auth_ldap_cache_timeout:
+
+* ``auth_ldap_cache_timeout``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--auth-ldap.cache-timeout`
+
+   How often to empty the users cache.
+
+.. _auth_ldap_mysql_password_attribute:
+
+* ``auth_ldap_mysql_password_attribute``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--auth-ldap.mysql-password-attribute`
+
+   Attribute in LDAP with MySQL hashed password.
+
+.. _auth_ldap_password_attribute:
+
+* ``auth_ldap_password_attribute``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--auth-ldap.password-attribute`
+
+   Attribute in LDAP with plain text password.
+
+.. _auth_ldap_uri:
+
+* ``auth_ldap_uri``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--auth-ldap.uri`
+
+   URI of the LDAP server to contact.
+
+.. _auth_ldap_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _auth_ldap_authors:
+
+Authors
+-------
+
+Eric Day
+
+.. _auth_ldap_version:
+
+Version
+-------
+
+This documentation applies to **auth_ldap 0.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='auth_ldap'
+
+Changelog
+---------
+
+v0.1
+^^^^
+* First release.

=== added directory 'plugin/auth_pam/docs'
=== added file 'plugin/auth_pam/docs/index.rst'
--- plugin/auth_pam/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/auth_pam/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,78 @@
+PAM Authenication
+=================
+
+:program:`auth_pam` is an authentication plugin that authentication connections
+using :abbr:`PAM (Pluggable Authentication Module)`.
+PAM is effectively your current Linux based user security. [1]_ 
+
+.. note:: Unload the :doc:`/plugins/auth_all/index` plugin before using this plugin.
+.. seealso:: :doc:`/administration/authentication` 
+
+.. _auth_pam_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=auth_pam
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`auth_pam_configuration` and :ref:`auth_pam_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _auth_pam_configuration:
+
+Configuration
+-------------
+
+This plugin does not have any command line options.
+
+.. _auth_pam_variables:
+
+Variables
+---------
+
+This plugin does not register any variables.
+
+.. _auth_pam_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _auth_pam_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _auth_pam_version:
+
+Version
+-------
+
+This documentation applies to **auth_pam 0.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='auth_pam'
+
+Changelog
+---------
+
+v0.1
+^^^^
+* First release.
+
+-------------------------------------------------------------------------------
+
+.. rubric:: Footnotes
+
+.. [1] `Understanding Drizzle user authentication options – Part 1 <http://ronaldbradford.com/blog/understanding-drizzle-authentication-options-part-1-2010-03-12/>`_
+

=== modified file 'plugin/auth_pam/plugin.ini'
--- plugin/auth_pam/plugin.ini	2011-03-05 18:07:59 +0000
+++ plugin/auth_pam/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=PAM Authenication Plugin
+title=PAM Authenication
 description=PAM based authenication.
 build_conditional="$ac_cv_libpam" = "yes"
 ldflags=${LTLIBPAM}

=== added directory 'plugin/benchmark/docs'
=== added file 'plugin/benchmark/docs/index.rst'
--- plugin/benchmark/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/benchmark/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,45 @@
+BENCHMARK Function
+==================
+
+The ``benchmark`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`benchmark-function`
+
+.. _benchmark_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=benchmark
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _benchmark_authors:
+
+Authors
+-------
+
+Devananda van der Veen
+
+.. _benchmark_version:
+
+Version
+-------
+
+This documentation applies to **benchmark 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='benchmark'
+
+Changelog
+---------
+
+v1.0
+^^^^
+* First release.

=== modified file 'plugin/benchmark/plugin.ini'
--- plugin/benchmark/plugin.ini	2009-11-29 17:17:21 +0000
+++ plugin/benchmark/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=UDF Plugin for Benchmark 
+title=BENCHMARK Function
 description=UDF Plugin for Benchmark
 load_by_default=yes
 sources=benchmarkudf.cc

=== added directory 'plugin/catalog/docs'
=== added file 'plugin/catalog/docs/index.rst'
--- plugin/catalog/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/catalog/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,39 @@
+Catalog System
+==============
+
+The :program:`catalog` plugin provides the low-level catalog system.
+
+.. _catalog_loading:
+
+Loading
+-------
+
+This plugin is loaded by default and it should not be unloaded because
+Drizzle will not start without this plugin.
+
+.. _catalog_configuration:
+
+Authors
+-------
+
+Brian Aker
+
+.. _catalog_version:
+
+Version
+-------
+
+This documentation applies to **catalog 0.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='catalog'
+
+Changelog
+---------
+
+v0.1
+^^^^
+* First release.

=== added directory 'plugin/charlength/docs'
=== added file 'plugin/charlength/docs/index.rst'
--- plugin/charlength/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/charlength/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,47 @@
+CHAR_LENGTH Function
+====================
+
+The ``charlength`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`char-length-function`
+
+* :ref:`character-length-function`
+
+.. _charlength_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=charlength
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _charlength_authors:
+
+Authors
+-------
+
+Devananda van der Veen
+
+.. _charlength_version:
+
+Version
+-------
+
+This documentation applies to **charlength 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='charlength'
+
+Changelog
+---------
+
+v1.0
+^^^^
+* First release.

=== modified file 'plugin/charlength/plugin.ini'
--- plugin/charlength/plugin.ini	2009-11-29 17:17:21 +0000
+++ plugin/charlength/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,4 +1,4 @@
 [plugin]
-title=UDF Plugin for CharLength
+title=CHAR_LENGTH Function
 description=UDF Plugin for returning number of characters in a string
 load_by_default=yes

=== added directory 'plugin/coercibility_function/docs'
=== added file 'plugin/coercibility_function/docs/index.rst'
--- plugin/coercibility_function/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/coercibility_function/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,44 @@
+COERCIBILITY Function
+=====================
+
+The ``coercibility_function`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`coercibility-function`
+
+.. _coercibility_function_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=coercibility_function
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _coercibility_function_authors:
+
+Authors
+-------
+
+Andrew Hutchings
+
+.. _coercibility_function_version:
+
+Version
+-------
+
+This documentation applies to **coercibility_function 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='coercibility_function'
+
+Changelog
+---------
+
+v1.0
+^^^^
+* First release.

=== modified file 'plugin/coercibility_function/plugin.ini'
--- plugin/coercibility_function/plugin.ini	2010-08-18 08:20:47 +0000
+++ plugin/coercibility_function/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=COERCIBILITY() Function
+title=COERCIBILITY Function
 description=Gets coercibility for an expression
 load_by_default=no
 disabled=yes

=== added directory 'plugin/collation_dictionary/docs'
=== added file 'plugin/collation_dictionary/docs/index.rst'
--- plugin/collation_dictionary/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/collation_dictionary/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,42 @@
+Character and Collation Dictionary
+==================================
+
+:program:`collation_dictionary` is a low-level plugin that provides
+character set and collation dictionaries.
+
+.. _collation_dictionary_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=collation_dictionary
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+Authors
+-------
+
+Brian Aker
+
+.. _collation_dictionary_version:
+
+Version
+-------
+
+This documentation applies to **collation_dictionary 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='collation_dictionary'
+
+Changelog
+---------
+
+v1.0
+^^^^
+* First release.

=== modified file 'plugin/collation_dictionary/plugin.ini'
--- plugin/collation_dictionary/plugin.ini	2010-04-11 15:50:01 +0000
+++ plugin/collation_dictionary/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=Character And Collation Dictionary
+title=Character and Collation Dictionary
 description=Dictionary plugins for character set and collation system.
 load_by_default=yes
 sources=

=== added directory 'plugin/compression/docs'
=== added file 'plugin/compression/docs/index.rst'
--- plugin/compression/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/compression/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,49 @@
+Compression Functions
+=====================
+
+The ``compression`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`compress-function`
+
+* :ref:`uncompress-function`
+
+* :ref:`uncompressed-length-function`
+
+.. _compression_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=compression
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _compression_authors:
+
+Authors
+-------
+
+Stewart Smith
+
+.. _compression_version:
+
+Version
+-------
+
+This documentation applies to **compression 1.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='compression'
+
+Changelog
+---------
+
+v1.1
+^^^^
+* First release.

=== modified file 'plugin/compression/plugin.ini'
--- plugin/compression/plugin.ini	2009-11-29 17:17:21 +0000
+++ plugin/compression/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=compression UDFs
+title=Compression Functions
 description=UDF Plugin for compression
 load_by_default=yes
 headers=compress.h uncompress.h uncompressed_length.h

=== added directory 'plugin/connection_id/docs'
=== added file 'plugin/connection_id/docs/index.rst'
--- plugin/connection_id/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/connection_id/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,45 @@
+CONNECTION_ID Function
+======================
+
+The ``connection_id`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`connection-id-function`
+
+.. _connection_id_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=connection_id
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _connection_id_authors:
+
+Authors
+-------
+
+Devananda van der Veen
+
+.. _connection_id_version:
+
+Version
+-------
+
+This documentation applies to **connection_id 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='connection_id'
+
+Changelog
+---------
+
+v1.0
+^^^^
+* First release.

=== modified file 'plugin/connection_id/plugin.ini'
--- plugin/connection_id/plugin.ini	2009-11-29 17:17:21 +0000
+++ plugin/connection_id/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=Connection ID UDF
+title=CONNECTION_ID Function
 description=UDF Plugin for connection_id function
 load_by_default=yes
 sources=connection_id.cc

=== added directory 'plugin/crc32/docs'
=== added file 'plugin/crc32/docs/index.rst'
--- plugin/crc32/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/crc32/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,45 @@
+CRC32 Function
+==============
+
+The ``crc32`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`crc32-function`
+
+.. _crc32_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=crc32
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _crc32_authors:
+
+Authors
+-------
+
+Stewart Smith
+
+.. _crc32_version:
+
+Version
+-------
+
+This documentation applies to **crc32 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='crc32'
+
+Changelog
+---------
+
+v1.0
+^^^^
+* First release.

=== modified file 'plugin/crc32/plugin.ini'
--- plugin/crc32/plugin.ini	2010-03-22 21:17:44 +0000
+++ plugin/crc32/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,6 +1,5 @@
 [plugin]
-name=crc32
-title=crc32 UDF
+title=CRC32 Function
 description=UDF Plugin for crc32
 version=1.0
 author=Stewart Smith

=== added directory 'plugin/debug/docs'
=== added file 'plugin/debug/docs/index.rst'
--- plugin/debug/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/debug/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,48 @@
+Debugging Functions
+===================
+
+The ``debug`` plugin provides these debugging functions:
+
+* ``ASSERT_AND_CRASH``
+* ``BACKTRACE``
+* ``TRACE``
+
+These functions are for Drizzle developers.
+
+.. _debug_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=debug
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _debug_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _debug_version:
+
+Version
+-------
+
+This documentation applies to **debug 1.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='debug'
+
+Changelog
+---------
+
+v1.1
+^^^^
+* First release.

=== modified file 'plugin/debug/plugin.ini'
--- plugin/debug/plugin.ini	2011-02-14 20:32:17 +0000
+++ plugin/debug/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,7 +1,6 @@
 [plugin]
-title=Kernel debugger utilities.
+title=Debugging Functions
 description=crash(), assert(), and additional developer style tools.
 load_by_default=no
 static=no
-sources=
-  module.cc
+sources=module.cc

=== added directory 'plugin/default_replicator/docs'
=== added file 'plugin/default_replicator/docs/index.rst'
--- plugin/default_replicator/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/default_replicator/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,64 @@
+Default Replicator
+==================
+
+:program:`default_replicator` is a simple replicator which replicates all
+write events to all appliers.
+
+.. seealso:: :doc:`/replication`
+
+.. _default_replicator_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`default_replicator_configuration` and
+:ref:`default_replicator_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=default_replicator
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _default_replicator_configuration:
+
+Configuration
+-------------
+
+This plugin does not have any command line options.
+
+.. _default_replicator_variables:
+
+Variables
+---------
+
+This plugin does not register any variables.
+
+.. _default_replicator_authors:
+
+Authors
+-------
+
+Jay Pipes
+
+.. _default_replicator_version:
+
+Version
+-------
+
+This documentation applies to **default_replicator 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='default_replicator'
+
+Changelog
+---------
+
+v1.0
+^^^^
+* First release.

=== modified file 'plugin/default_replicator/plugin.ini'
--- plugin/default_replicator/plugin.ini	2010-08-17 20:57:43 +0000
+++ plugin/default_replicator/plugin.ini	2011-08-13 20:41:38 +0000
@@ -5,3 +5,4 @@
 sources=default_replicator.cc
 headers=default_replicator.h
 extra_dist=AUTHORS
+version=1.0

=== added directory 'plugin/drizzle_protocol/docs'
=== added file 'plugin/drizzle_protocol/docs/index.rst'
--- plugin/drizzle_protocol/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/drizzle_protocol/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,202 @@
+Drizzle Protocol
+================
+
+:program:`drizzle_protocol` implements the Drizzle network protocol.
+
+.. _drizzle_protocol_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`drizzle_protocol_configuration` and
+:ref:`drizzle_protocol_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=drizzle_protocol
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _drizzle_protocol_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. option:: --drizzle-protocol.bind-address ARG
+
+   :Default: localhost
+   :Variable: :ref:`drizzle_protocol_bind_address <drizzle_protocol_bind_address>`
+
+   Address to bind to.
+
+.. option:: --drizzle-protocol.buffer-length ARG
+
+   :Default: 16384
+   :Variable: :ref:`drizzle_protocol_buffer_length <drizzle_protocol_buffer_length>`
+
+   Buffer length.
+
+.. option:: --drizzle-protocol.connect-timeout ARG
+
+   :Default: 10
+   :Variable: :ref:`drizzle_protocol_connect_timeout <drizzle_protocol_connect_timeout>`
+
+   Connect Timeout.
+
+.. option:: --drizzle-protocol.max-connections ARG
+
+   :Default: 1000
+   :Variable: :ref:`drizzle_protocol_max_connections <drizzle_protocol_max_connections>`
+
+   Maximum simultaneous connections.
+
+.. option:: --drizzle-protocol.port ARG
+
+   :Default: 4427
+   :Variable: :ref:`drizzle_protocol_port <drizzle_protocol_port>`
+
+   Port number to use for connection or 0 for default to with Drizzle/MySQL protocol.
+
+.. option:: --drizzle-protocol.read-timeout ARG
+
+   :Default: 30
+   :Variable: :ref:`drizzle_protocol_read_timeout <drizzle_protocol_read_timeout>`
+
+   Read Timeout.
+
+.. option:: --drizzle-protocol.retry-count ARG
+
+   :Default: 10
+   :Variable: :ref:`drizzle_protocol_retry_count <drizzle_protocol_retry_count>`
+
+   Retry Count.
+
+.. option:: --drizzle-protocol.write-timeout ARG
+
+   :Default: 60
+   :Variable: :ref:`drizzle_protocol_write_timeout <drizzle_protocol_write_timeout>`
+
+   Write Timeout.
+
+.. _drizzle_protocol_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _drizzle_protocol_bind_address:
+
+* ``drizzle_protocol_bind_address``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--drizzle-protocol.bind-address`
+
+   Address to bind to.
+
+.. _drizzle_protocol_buffer_length:
+
+* ``drizzle_protocol_buffer_length``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--drizzle-protocol.buffer-length`
+
+   Buffer length.
+
+.. _drizzle_protocol_connect_timeout:
+
+* ``drizzle_protocol_connect_timeout``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--drizzle-protocol.connect-timeout`
+
+   Connect Timeout.
+
+.. _drizzle_protocol_max_connections:
+
+* ``drizzle_protocol_max_connections``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--drizzle-protocol.max-connections`
+
+   Maximum simultaneous connections.
+
+.. _drizzle_protocol_port:
+
+* ``drizzle_protocol_port``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--drizzle-protocol.port`
+
+   Port number to use for connection or 0 for default to with Drizzle/MySQL protocol.
+
+.. _drizzle_protocol_read_timeout:
+
+* ``drizzle_protocol_read_timeout``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--drizzle-protocol.read-timeout`
+
+   Read Timeout.
+
+.. _drizzle_protocol_retry_count:
+
+* ``drizzle_protocol_retry_count``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--drizzle-protocol.retry-count`
+
+   Retry Count.
+
+.. _drizzle_protocol_write_timeout:
+
+* ``drizzle_protocol_write_timeout``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--drizzle-protocol.write-timeout`
+
+   Write Timeout.
+
+.. _drizzle_protocol_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _drizzle_protocol_version:
+
+Version
+-------
+
+This documentation applies to **drizzle_protocol 0.3**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='drizzle_protocol'
+
+Changelog
+---------
+
+v0.3
+^^^^
+* First release.

=== modified file 'plugin/drizzle_protocol/plugin.ini'
--- plugin/drizzle_protocol/plugin.ini	2011-01-31 14:45:30 +0000
+++ plugin/drizzle_protocol/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=Drizzle Protocol Module
+title=Drizzle Protocol
 description=Drizzle protocol module.
 version=0.3
 author=Brian Aker

=== added directory 'plugin/errmsg_stderr/docs'
=== added file 'plugin/errmsg_stderr/docs/index.rst'
--- plugin/errmsg_stderr/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/errmsg_stderr/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,73 @@
+Error Messages To STDERR
+========================
+
+:program:`errmsg_stderr` is an error message plugin that prints all
+:program:`drizzled`: error messages to ``STDERR``.  Only server errors are
+printed; SQL errors, replication errors, etc. are not captured by error
+message plugins.
+
+.. _errmsg_stderr_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`errmsg_stderr_configuration` and
+:ref:`errmsg_stderr_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=errmsg_stderr
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _errmsg_stderr_configuration:
+
+Configuration
+-------------
+
+This plugin does not have any command line options.
+
+.. _errmsg_stderr_variables:
+
+Variables
+---------
+
+This plugin does not register any variables.
+
+.. _errmsg_stderr_examples:
+
+Examples
+--------
+
+Redirect ``STDOUT`` and ``STDERR`` to :file:`drizzled.err`::
+
+   sbin/drizzled >> drizzled.err 2>&1
+
+.. _errmsg_stderr_authors:
+
+Authors
+-------
+
+Mark Atwood
+
+.. _errmsg_stderr_version:
+
+Version
+-------
+
+This documentation applies to **errmsg_stderr 0.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='errmsg_stderr'
+
+Changelog
+---------
+
+v0.1
+^^^^
+* First release.

=== modified file 'plugin/errmsg_stderr/plugin.ini'
--- plugin/errmsg_stderr/plugin.ini	2009-11-29 18:30:06 +0000
+++ plugin/errmsg_stderr/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,4 +1,4 @@
 [plugin]
-title=Error Message Plugin
+title=Error Messages To STDERR
 description=Errmsg Plugin that sends messages to stderr.
 load_by_default=yes

=== added directory 'plugin/error_dictionary/docs'
=== added file 'plugin/error_dictionary/docs/index.rst'
--- plugin/error_dictionary/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/error_dictionary/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,67 @@
+Error Dictionary
+================
+
+:program:`error_dictionary` creates the ``ERRORS`` dictionary which lists
+the error codes and messages generated by Drizzle.
+
+.. _error_dictionary_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by default,
+start :program:`drizzled` with::
+
+   --plugin-remove=error_dictionary
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _error_dictionary_configuration:
+
+Examples
+--------
+
+List Drizzle's error codes and messages:
+
+.. code-block:: mysql
+
+   drizzle> SELECT * FROM DATA_DICTIONARY.ERRORS\G
+   *************************** 1. row ***************************
+        ERROR_CODE: 1167
+        ERROR_NAME: ER_WRONG_KEY_COLUMN
+     ERROR_MESSAGE: The used storage engine can't index column '%-.192s'
+   ERROR_SQL_STATE: 42000
+   *************************** 2. row ***************************
+        ERROR_CODE: 0
+        ERROR_NAME: EE_OK
+     ERROR_MESSAGE: SUCCESS
+   ERROR_SQL_STATE: HY000
+
+   -- Hundreds more...
+
+.. _error_dictionary_authors:
+
+Authors
+-------
+
+Monty Taylor
+
+.. _error_dictionary_version:
+
+Version
+-------
+
+This documentation applies to **error_dictionary 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='error_dictionary'
+
+Changelog
+---------
+
+v1.0
+^^^^
+* First release.

=== modified file 'plugin/error_dictionary/plugin.ini'
--- plugin/error_dictionary/plugin.ini	2010-12-16 00:11:51 +0000
+++ plugin/error_dictionary/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=Error Code data dictionary tables.
+title=Error Dictionary
 description=List the error codes and messages genearted by Drizzle.
 load_by_default=yes
 static=yes

=== modified file 'plugin/filtered_replicator/docs/index.rst'
--- plugin/filtered_replicator/docs/index.rst	2011-03-08 19:12:48 +0000
+++ plugin/filtered_replicator/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -1,53 +1,143 @@
-*******************
 Filtered Replicator
-*******************
-
-Description
-###########
-
-The Filtered Replicator plugin registers itself in the Drizzle kernel replication
-stream process as a new replicator (see :ref:`replication_streams` for more
-information). It provides a way to filter replication messages by schema name or
-table name. Regular expressions can be used for the schema and table names.
-
-To make the filtered replicator available, you must enable the plugin when the
-server is started using the :option:`--plugin-add` option.
+===================
+
+The Filtered Replicator plugin registers itself in the Drizzle kernel
+replication stream process as a new replicator (see :ref:`replication_streams`
+for more information). It provides a way to filter replication messages by
+schema name or table name.  Regular expressions can be used for the schema and
+table names.
+
+.. _filtered_replicator_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=filtered_replicator
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`filtered_replicator_configuration` and :ref:`filtered_replicator_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _filtered_replicator_configuration:
 
 Configuration
-#############
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
 
 .. program:: drizzled
 
-.. option:: --filtered-replicator.filteredschemas
-
-   Comma-separated list of schema names to exclude from replication.
-
-.. option:: --filtered-replicator.filteredtables
-
-   Comma-separated list of table names to exclude from replication.
-
-.. option:: --filtered-replicator.schemaregex
-
-   Regular expression to apply to schemas to exclude from replication.
-
-.. option:: --filtered-replicator.tableregex
-
-   Regular expression to apply to tables to exclude from replication.
+.. option:: --filtered-replicator.filteredschemas ARG
+
+   :Default: 
+   :Variable: :ref:`filtered_replicator_filteredschemas <filtered_replicator_filteredschemas>`
+
+   Comma-separated list of schemas to exclude from replication.
+
+.. option:: --filtered-replicator.filteredtables ARG
+
+   :Default: 
+   :Variable: :ref:`filtered_replicator_filteredtables <filtered_replicator_filteredtables>`
+
+   Comma-separated list of tables to exclude from replication.
+
+.. option:: --filtered-replicator.schemaregex ARG
+
+   :Default: 
+   :Variable: :ref:`filtered_replicator_schemaregex <filtered_replicator_schemaregex>`
+
+   Regular expression to apply to schemas to exclude from replication.
+
+.. option:: --filtered-replicator.tableregex ARG
+
+   :Default: 
+   :Variable: :ref:`filtered_replicator_tableregex <filtered_replicator_tableregex>`
+
+   Regular expression to apply to tables to exclude from replication.
+
+.. _filtered_replicator_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _filtered_replicator_filteredschemas:
+
+* ``filtered_replicator_filteredschemas``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--filtered-replicator.filteredschemas`
+
+   Comma-separated list of schemas to exclude from replication.
+
+.. _filtered_replicator_filteredtables:
+
+* ``filtered_replicator_filteredtables``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--filtered-replicator.filteredtables`
+
+   Comma-separated list of tables to exclude from replication.
+
+.. _filtered_replicator_schemaregex:
+
+* ``filtered_replicator_schemaregex``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--filtered-replicator.schemaregex`
+
+   Regular expression to apply to schemas to exclude from replication.
+
+.. _filtered_replicator_tableregex:
+
+* ``filtered_replicator_tableregex``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--filtered-replicator.tableregex`
+
+   Regular expression to apply to tables to exclude from replication.
+
+.. _filtered_replicator_examples:
 
 Examples
-########
-
-To prevent changes to the *foo* schema from being replicated::
-
-  sbin/drizzled --plugin-add=filtered_replicator \
-                --filtered-replicator.filteredschemas=foo
-
-To prevent changes to any schema beginning with *test* from being replicated::
-
-  sbin/drizzled --plugin-add=filtered_replicator \
-                --filtered-replicator.schemaregex="test*"
-
-To prevent changes to any table beginning with *junk* from being replicated::
-
-  sbin/drizzled --plugin-add=filtered_replicator \
-                --filtered-replicator.tableregex="junk*"
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _filtered_replicator_authors:
+
+Authors
+-------
+
+Padraig O Sullivan
+
+.. _filtered_replicator_version:
+
+Version
+-------
+
+This documentation applies to **filtered_replicator 0.2**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='filtered_replicator'
+
+Chagnelog
+---------
+
+v0.2
+^^^^
+* First release.

=== added directory 'plugin/function_dictionary/docs'
=== added file 'plugin/function_dictionary/docs/index.rst'
--- plugin/function_dictionary/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/function_dictionary/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,62 @@
+Function Dictionary
+===================
+
+:program:`function_dictionary` creates the ``FUNCTIONS`` dictionary which lists
+available functions.
+
+.. _function_dictionary_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=function_dictionary
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _function_dictionary_examples:
+
+Examples
+--------
+
+List all available functions:
+
+.. code-block:: mysql
+
+   drizzle> SELECT * FROM DATA_DICTIONARY.FUNCTIONS;
+   +-----------------------+
+   | FUNCTION_NAME         |
+   +-----------------------+
+   | LOWER                 | 
+   | LAST_INSERT_ID        | 
+   | LTRIM                 | 
+   | GREATEST              | 
+   ...
+
+.. _function_dictionary_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _function_dictionary_version:
+
+Version
+-------
+
+This documentation applies to **function_dictionary 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='function_dictionary'
+
+Changelog
+---------
+
+v1.0
+^^^^
+* First release.

=== modified file 'plugin/function_dictionary/plugin.ini'
--- plugin/function_dictionary/plugin.ini	2010-09-15 19:55:21 +0000
+++ plugin/function_dictionary/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=Function data dictionary tables.
+title=Function Dictionary
 description= List the functions available to SQL developers.
 load_by_default=no
 static=no

=== added directory 'plugin/function_engine/docs'
=== added file 'plugin/function_engine/docs/index.rst'
--- plugin/function_engine/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/function_engine/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,45 @@
+Function Engine
+===============
+
+:program:`function_engine` is a low-level plugin that provides the
+interface for other function plugins.
+
+.. warning::
+
+   Drizzle depends on the :program:`function_engine` plugin.  If it is not
+   loaded, most commands will not work and ``DATA_DICTIONARY`` and
+   ``INFORMATION_SCHEMA`` will not be available.
+
+.. _function_engine_loading:
+
+Loading
+-------
+
+This plugin is loaded by default and it should not be unloaded.  See the
+warning above.
+
+
+Authors
+-------
+
+Brian Aker
+
+.. _function_engine_version:
+
+Version
+-------
+
+This documentation applies to **function_engine 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='function_engine'
+
+Changelog
+---------
+
+v1.0
+^^^^
+* First release.

=== modified file 'plugin/function_engine/plugin.ini'
--- plugin/function_engine/plugin.ini	2010-04-11 15:50:01 +0000
+++ plugin/function_engine/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=Data Engine
+title=Function Engine
 description=Function Engine used for Table Functions.
 load_by_default=yes
 sources=

=== modified file 'plugin/gearman_udf/plugin.ini'
--- plugin/gearman_udf/plugin.ini	2010-09-15 20:24:31 +0000
+++ plugin/gearman_udf/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=Gearman Client UDFs
+title=Gearman Client
 description=UDF plugin that provides a Gearman client interface
 load_by_default=no
 static=no

=== modified file 'plugin/hello_events/plugin.ini'
--- plugin/hello_events/plugin.ini	2010-05-06 14:23:27 +0000
+++ plugin/hello_events/plugin.ini	2011-08-13 20:41:38 +0000
@@ -4,4 +4,4 @@
 description=An example event observer Plugin for Drizzle
 load_by_default=no
 sources=hello_events.cc
-headers=hello_events.h
\ No newline at end of file
+headers=hello_events.h

=== added directory 'plugin/hex_functions/docs'
=== added file 'plugin/hex_functions/docs/index.rst'
--- plugin/hex_functions/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/hex_functions/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,47 @@
+Hex Functions
+=============
+
+The ``hex_functions`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`hex-function`
+
+* :ref:`unhex-function`
+
+.. _hex_functions_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=hex_functions
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _hex_functions_authors:
+
+Authors
+-------
+
+Stewart Smith
+
+.. _hex_functions_version:
+
+Version
+-------
+
+This documentation applies to **hex_functions 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='hex_functions'
+
+Changelog
+---------
+
+v1.0
+^^^^
+* First release.

=== modified file 'plugin/hex_functions/plugin.ini'
--- plugin/hex_functions/plugin.ini	2010-02-15 02:54:58 +0000
+++ plugin/hex_functions/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,4 +1,4 @@
 [plugin]
-title=HEX() and UNHEX() functions
+title=Hex Functions
 description=converting strings to and from hexadecimal
 load_by_default=yes

=== added directory 'plugin/http_functions/docs'
=== added file 'plugin/http_functions/docs/index.rst'
--- plugin/http_functions/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/http_functions/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,64 @@
+HTTP Functions
+==============
+
+The ``http_functions`` plugin provides functions to get and post HTTP
+data:
+
+* ``HTTP_GET``
+* ``HTTP_POST``
+
+.. _http_functions_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=http_functions
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _http_functions_authors:
+
+Examples
+--------
+
+Start :program:`drizzled` with the plugin::
+
+   sbin/drizzled --plugin-add=http_functions
+
+Get `www.drizzle.org <http://www.drizzle.org>`_:
+
+.. code-block:: mysql
+
+   drizzle> SELECT HTTP_GET('www.drizzle.org')\G
+   *************************** 1. row ***************************
+   HTTP_GET('www.drizzle.org'): <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML+RDFa 1.0//EN"
+   "http://www.w3.org/MarkUp/DTD/xhtml-rdfa-1.dtd">
+   <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" version="XHTML+RDFa 1.0" dir="ltr"
+   ...
+
+Authors
+-------
+
+Stewart Smith
+
+.. _http_functions_version:
+
+Version
+-------
+
+This documentation applies to **http_functions 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='http_functions'
+
+Changelog
+---------
+
+v1.0
+^^^^
+* First release.

=== modified file 'plugin/http_functions/plugin.ini'
--- plugin/http_functions/plugin.ini	2011-05-02 07:25:30 +0000
+++ plugin/http_functions/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=HTTP functions
+title=HTTP Functions
 description=HTTP functions: HTTP_GET() etc
 sources=http_functions.cc
 build_conditional="${ac_cv_libcurl}" = "yes"

=== added directory 'plugin/information_schema_dictionary/docs'
=== added file 'plugin/information_schema_dictionary/docs/index.rst'
--- plugin/information_schema_dictionary/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/information_schema_dictionary/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,67 @@
+Information Schema Dictionary
+=============================
+
+Data Dictionary for ANSI information schema.
+
+.. _information_schema_dictionary_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`information_schema_dictionary_configuration` and
+:ref:`information_schema_dictionary_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=information_schema_dictionary
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _information_schema_dictionary_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _information_schema_dictionary_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _information_schema_dictionary_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _information_schema_dictionary_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _information_schema_dictionary_version:
+
+Version
+-------
+
+This documentation applies to **information_schema_dictionary 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='information_schema_dictionary'
+

=== added directory 'plugin/json_server/docs'
=== added file 'plugin/json_server/docs/index.rst'
--- plugin/json_server/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/json_server/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,82 @@
+JSON Server
+===========
+
+JSON HTTP interface.
+
+.. _json_server_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=json_server
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`json_server_configuration` and :ref:`json_server_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _json_server_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. option:: --json-server.port ARG
+
+   :Default: 8086
+   :Variable: :ref:`json_server_port <json_server_port>`
+
+   Port number to use for connection or 0 for default (port 8086) 
+
+.. _json_server_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _json_server_port:
+
+* ``json_server_port``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--json-server.port`
+
+   Port number to use for connection or 0 for default (port 8086) 
+
+.. _json_server_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _json_server_authors:
+
+Authors
+-------
+
+Stewart Smith
+
+.. _json_server_version:
+
+Version
+-------
+
+This documentation applies to **json_server 0.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='json_server'
+

=== modified file 'plugin/json_server/plugin.ini'
--- plugin/json_server/plugin.ini	2011-07-12 23:34:13 +0000
+++ plugin/json_server/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=JSON HTTP interface
+title=JSON Server
 description=libevent based http server with JSON interface
 version=0.1
 author=Stewart Smith

=== added directory 'plugin/length/docs'
=== added file 'plugin/length/docs/index.rst'
--- plugin/length/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/length/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,41 @@
+Length Functions
+================
+
+The ``length`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`length-function`
+
+* :ref:`octet-length-function`
+
+.. _length_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=length
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _length_authors:
+
+Authors
+-------
+
+Devananda van der Veen
+
+.. _length_version:
+
+Version
+-------
+
+This documentation applies to **length 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='length'
+

=== modified file 'plugin/length/plugin.ini'
--- plugin/length/plugin.ini	2009-11-29 18:31:46 +0000
+++ plugin/length/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,4 +1,4 @@
 [plugin]
-title=UDF Plugin for Length
+title=Length Functions
 description=UDF Plugin for returning byte length of a string
 load_by_default=yes

=== added directory 'plugin/logging_gearman/docs'
=== added file 'plugin/logging_gearman/docs/index.rst'
--- plugin/logging_gearman/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/logging_gearman/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,99 @@
+Gearman Logging
+===============
+
+N_("Log queries to a Gearman server").
+
+.. _logging_gearman_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=logging_gearman
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`logging_gearman_configuration` and :ref:`logging_gearman_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _logging_gearman_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. option:: --logging-gearman.function ARG
+
+   :Default: drizzlelog
+   :Variable: :ref:`logging_gearman_function <logging_gearman_function>`
+
+   Gearman Function to send logging to
+
+.. option:: --logging-gearman.host ARG
+
+   :Default: localhost
+   :Variable: :ref:`logging_gearman_host <logging_gearman_host>`
+
+   Hostname for logging to a Gearman server
+
+.. _logging_gearman_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _logging_gearman_function:
+
+* ``logging_gearman_function``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--logging-gearman.function`
+
+   Gearman Function to send logging to
+
+.. _logging_gearman_host:
+
+* ``logging_gearman_host``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--logging-gearman.host`
+
+   Hostname for logging to a Gearman server
+
+.. _logging_gearman_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _logging_gearman_authors:
+
+Authors
+-------
+
+Mark Atwood
+
+.. _logging_gearman_version:
+
+Version
+-------
+
+This documentation applies to **logging_gearman 0.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='logging_gearman'
+

=== modified file 'plugin/logging_gearman/plugin.ini'
--- plugin/logging_gearman/plugin.ini	2009-11-29 19:55:08 +0000
+++ plugin/logging_gearman/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=Gearman Logging Plugin
+title=Gearman Logging
 description=Logging Plugin that logs to Gearman.
 ldflags= ${LTLIBGEARMAN}
 sources= logging_gearman.cc

=== added directory 'plugin/logging_query/docs'
=== added file 'plugin/logging_query/docs/index.rst'
--- plugin/logging_query/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/logging_query/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,167 @@
+Query Logging
+=============
+
+N_("Log queries to a CSV file").
+
+.. _logging_query_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=logging_query
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`logging_query_configuration` and :ref:`logging_query_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _logging_query_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. option:: --logging-query.enable 
+
+   :Default: false
+   :Variable: :ref:`logging_query_enable <logging_query_enable>`
+
+   Enable logging to CSV file
+
+.. option:: --logging-query.filename 
+
+   :Default: 
+   :Variable: :ref:`logging_query_filename <logging_query_filename>`
+
+   File to log to
+
+.. option:: --logging-query.pcre ARG
+
+   :Default: 
+   :Variable: :ref:`logging_query_pcre <logging_query_pcre>`
+
+   PCRE to match the query against
+
+.. option:: --logging-query.threshold-big-examined 
+
+   :Default: 0
+   :Variable: :ref:`logging_query_threshold_big_examined <logging_query_threshold_big_examined>`
+
+   Threshold for logging big queries
+
+.. option:: --logging-query.threshold-big-resultset 
+
+   :Default: 0
+   :Variable: :ref:`logging_query_threshold_big_resultset <logging_query_threshold_big_resultset>`
+
+   Threshold for logging big queries
+
+.. option:: --logging-query.threshold-slow 
+
+   :Default: 0
+   :Variable: :ref:`logging_query_threshold_slow <logging_query_threshold_slow>`
+
+   Threshold for logging slow queries
+
+.. _logging_query_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _logging_query_enable:
+
+* ``logging_query_enable``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--logging-query.enable`
+
+   Enable logging to CSV file
+
+.. _logging_query_filename:
+
+* ``logging_query_filename``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--logging-query.filename`
+
+   File to log to
+
+.. _logging_query_pcre:
+
+* ``logging_query_pcre``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--logging-query.pcre`
+
+   PCRE to match the query against
+
+.. _logging_query_threshold_big_examined:
+
+* ``logging_query_threshold_big_examined``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--logging-query.threshold-big-examined`
+
+   Threshold for logging big queries
+
+.. _logging_query_threshold_big_resultset:
+
+* ``logging_query_threshold_big_resultset``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--logging-query.threshold-big-resultset`
+
+   Threshold for logging big queries
+
+.. _logging_query_threshold_slow:
+
+* ``logging_query_threshold_slow``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--logging-query.threshold-slow`
+
+   Threshold for logging slow queries
+
+.. _logging_query_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _logging_query_authors:
+
+Authors
+-------
+
+Mark Atwood
+
+.. _logging_query_version:
+
+Version
+-------
+
+This documentation applies to **logging_query 0.2**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='logging_query'
+

=== modified file 'plugin/logging_query/plugin.ini'
--- plugin/logging_query/plugin.ini	2010-06-09 23:19:41 +0000
+++ plugin/logging_query/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,4 +1,4 @@
 [plugin]
-title=Query Logging Plugin
+title=Query Logging
 description=Logging Plugin that logs all queries.
 cxxflags=${BOOSTSKIP_WARNINGS}

=== added directory 'plugin/logging_stats/docs'
=== added file 'plugin/logging_stats/docs/index.rst'
--- plugin/logging_stats/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/logging_stats/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,135 @@
+Statistics
+==========
+
+N_("User Statistics as DATA_DICTIONARY tables").
+
+.. _logging_stats_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`logging_stats_configuration` and
+:ref:`logging_stats_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=logging_stats
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _logging_stats_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. option:: --logging-stats.bucket-count ARG
+
+   :Default: 10
+   :Variable: :ref:`logging_stats_bucket_count <logging_stats_bucket_count>`
+
+   Max number of range locks to use for Scoreboard
+
+.. option:: --logging-stats.disable 
+
+   :Default: 
+   :Variable:
+
+   Enable Logging Statistics Collection
+
+.. option:: --logging-stats.max-user-count ARG
+
+   :Default: 500
+   :Variable: :ref:`logging_stats_max_user_count <logging_stats_max_user_count>`
+
+   Max number of users that will be logged
+
+.. option:: --logging-stats.scoreboard-size ARG
+
+   :Default: 2000
+   :Variable: :ref:`logging_stats_scoreboard_size <logging_stats_scoreboard_size>`
+
+   Max number of concurrent sessions that will be logged
+
+.. _logging_stats_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _logging_stats_bucket_count:
+
+* ``logging_stats_bucket_count``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--logging-stats.bucket-count`
+
+   Max number of range locks to use for Scoreboard
+
+.. _logging_stats_enable:
+
+* ``logging_stats_enable``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option:
+
+   Unknown
+
+.. _logging_stats_max_user_count:
+
+* ``logging_stats_max_user_count``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--logging-stats.max-user-count`
+
+   Max number of users that will be logged
+
+.. _logging_stats_scoreboard_size:
+
+* ``logging_stats_scoreboard_size``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--logging-stats.scoreboard-size`
+
+   Max number of concurrent sessions that will be logged
+
+.. _logging_stats_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _logging_stats_authors:
+
+Authors
+-------
+
+Joseph Daly
+
+.. _logging_stats_version:
+
+Version
+-------
+
+This documentation applies to **logging_stats 0.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='logging_stats'
+

=== modified file 'plugin/logging_stats/plugin.ini'
--- plugin/logging_stats/plugin.ini	2010-10-26 20:40:42 +0000
+++ plugin/logging_stats/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,6 +1,5 @@
 [plugin]
-name=logging_stats
-title=Statistics Plugin for Drizzle
+title=Statistics
 description=Statistics Plugin for Drizzle
 sources=logging_stats.cc user_commands.cc stats_schema.cc scoreboard_slot.cc scoreboard.cc cumulative_stats.cc global_stats.cc status_vars.cc status_tool.cc
 headers=logging_stats.h user_commands.h scoreboard_slot.h stats_schema.h scoreboard.h cumulative_stats.h global_stats.h status_vars.h status_tool.h

=== added directory 'plugin/math_functions/docs'
=== added file 'plugin/math_functions/docs/index.rst'
--- plugin/math_functions/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/math_functions/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,75 @@
+Math Functions
+==============
+
+The ``math_functions`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`abs-function`
+
+* :ref:`acos-function`
+
+* :ref:`asin-function`
+
+* :ref:`atan-function`
+
+* :ref:`atan2-function`
+
+* :ref:`cos-function`
+
+* :ref:`log-function`
+
+* :ref:`log2-function`
+
+* :ref:`log10-function`
+
+* :ref:`sin-function`
+
+* :ref:`pow-function`
+
+* :ref:`power-function`
+
+* :ref:`ln-function`
+
+* :ref:`sqrt-function`
+
+* :ref:`ceil-function`
+
+* :ref:`ceiling-function`
+
+* :ref:`exp-function`
+
+* :ref:`floor-function`
+
+* :ref:`ord-function`
+
+.. _math_functions_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=math_functions
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _math_functions_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _math_functions_version:
+
+Version
+-------
+
+This documentation applies to **math_functions 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='math_functions'
+

=== modified file 'plugin/math_functions/plugin.ini'
--- plugin/math_functions/plugin.ini	2010-09-20 05:44:27 +0000
+++ plugin/math_functions/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,6 +1,6 @@
 [plugin]
 title=Math Functions
-description= Math Functions
+description=Math Functions
 load_by_default=yes
 sources= 
   functions.cc abs.cc acos.cc asin.cc atan.cc ceiling.cc cos.cc exp.cc floor.cc log.cc sin.cc ord.cc pow.cc ln.cc sqrt.cc

=== added directory 'plugin/md5/docs'
=== added file 'plugin/md5/docs/index.rst'
--- plugin/md5/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/md5/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,39 @@
+MD5 Function
+============
+
+The ``md5`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`md5-function`
+
+.. _md5_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=md5
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _md5_authors:
+
+Authors
+-------
+
+Stewart Smith
+
+.. _md5_version:
+
+Version
+-------
+
+This documentation applies to **md5 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='md5'
+

=== modified file 'plugin/md5/plugin.ini'
--- plugin/md5/plugin.ini	2010-03-23 10:28:09 +0000
+++ plugin/md5/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=UDF Plugin for MD5
+title=MD5 Function
 description=UDF Plugin for MD5
 load_by_default=yes
 ldflags=${LTLIBGCRYPT}

=== added directory 'plugin/memcached_functions/docs'
=== added file 'plugin/memcached_functions/docs/index.rst'
--- plugin/memcached_functions/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,65 @@
+Memcached Functions
+===================
+
+Ronald Bradford.
+
+.. _memcached_functions_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=memcached_functions
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`memcached_functions_configuration` and :ref:`memcached_functions_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _memcached_functions_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _memcached_functions_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _memcached_functions_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _memcached_functions_authors:
+
+Authors
+-------
+
+Patrick Galbraith
+
+.. _memcached_functions_version:
+
+Version
+-------
+
+This documentation applies to **memcached_functions 0.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='memcached_functions'
+

=== modified file 'plugin/memcached_functions/plugin.ini'
--- plugin/memcached_functions/plugin.ini	2010-09-15 20:24:31 +0000
+++ plugin/memcached_functions/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=Memcached Client UDFs
+title=Memcached Functions
 description=UDF plugin for libmemcached
 load_by_default=no
 static=no

=== added directory 'plugin/memcached_stats/docs'
=== added file 'plugin/memcached_stats/docs/index.rst'
--- plugin/memcached_stats/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/memcached_stats/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,82 @@
+Memcached Statistics
+====================
+
+N_("Memcached Stats as I_S tables").
+
+.. _memcached_stats_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=memcached_stats
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`memcached_stats_configuration` and :ref:`memcached_stats_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _memcached_stats_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. option:: --memcached-stats.servers ARG
+
+   :Default: 
+   :Variable:
+
+   List of memcached servers.
+
+.. _memcached_stats_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _memcached_stats_servers:
+
+* ``memcached_stats_servers``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option:
+
+   Unknown
+
+.. _memcached_stats_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _memcached_stats_authors:
+
+Authors
+-------
+
+Padraig O'Sullivan
+
+.. _memcached_stats_version:
+
+Version
+-------
+
+This documentation applies to **memcached_stats 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='memcached_stats'
+

=== modified file 'plugin/memcached_stats/plugin.ini'
--- plugin/memcached_stats/plugin.ini	2010-12-02 23:49:02 +0000
+++ plugin/memcached_stats/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=Memcached Stats in DATA_DICTIONARY tables
+title=Memcached Statistics
 description=Some DATA_DICTIONARY tables that provide Memcached stats
 load_by_default=no
 static=no

=== added directory 'plugin/memory/docs'
=== added file 'plugin/memory/docs/index.rst'
--- plugin/memory/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/memory/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,67 @@
+Memory Storage Engine
+=====================
+
+Hash based.
+
+.. _memory_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`memory_configuration` and
+:ref:`memory_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=memory
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _memory_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _memory_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _memory_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _memory_authors:
+
+Authors
+-------
+
+MySQL AB
+
+.. _memory_version:
+
+Version
+-------
+
+This documentation applies to **memory 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='memory'
+

=== added directory 'plugin/multi_thread/docs'
=== added file 'plugin/multi_thread/docs/index.rst'
--- plugin/multi_thread/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/multi_thread/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,74 @@
+Multi-Thread Scheduler
+======================
+
+One Thread Per Session Scheduler.
+
+.. _multi_thread_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`multi_thread_configuration` and
+:ref:`multi_thread_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=multi_thread
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _multi_thread_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. option:: --multi-thread.max-threads ARG
+
+   :Default: 2048
+   :Variable:
+
+   Maximum number of user threads available.
+
+.. _multi_thread_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _multi_thread_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _multi_thread_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _multi_thread_version:
+
+Version
+-------
+
+This documentation applies to **multi_thread 0.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='multi_thread'
+

=== modified file 'plugin/multi_thread/plugin.ini'
--- plugin/multi_thread/plugin.ini	2009-11-12 00:45:29 +0000
+++ plugin/multi_thread/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-headers=multi_thread.h
 title=Multi-Thread Scheduler
 description=One Thread Per Connection Scheduler
 load_by_default=yes
+headers=multi_thread.h

=== added directory 'plugin/myisam/docs'
=== added file 'plugin/myisam/docs/index.rst'
--- plugin/myisam/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/myisam/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,101 @@
+MyISAM Storage Engine
+=====================
+
+Default engine as of MySQL 3.23 with great performance.
+
+.. _myisam_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`myisam_configuration` and
+:ref:`myisam_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=myisam
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _myisam_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. option:: --myisam.max-sort-file-size ARG
+
+   :Default: INT32_MAX
+   :Variable: :ref:`myisam_max_sort_file_size <myisam_max_sort_file_size>`
+
+   Don't use the fast sort index method to created index if the temporary file would get bigger than this.
+
+.. option:: --myisam.sort-buffer-size ARG
+
+   :Default: 8192*1024
+   :Variable: :ref:`myisam_sort_buffer_size <myisam_sort_buffer_size>`
+
+   The buffer that is allocated when sorting the index when doing a REPAIR or when creating indexes with CREATE INDEX or ALTER TABLE.
+
+.. _myisam_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _myisam_max_sort_file_size:
+
+* ``myisam_max_sort_file_size``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--myisam.max-sort-file-size`
+
+   Don't use the fast sort index method to created index if the temporary file would get bigger than this.
+
+.. _myisam_sort_buffer_size:
+
+* ``myisam_sort_buffer_size``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--myisam.sort-buffer-size`
+
+   The buffer that is allocated when sorting the index when doing a REPAIR or when creating indexes with CREATE INDEX or ALTER TABLE.
+
+.. _myisam_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _myisam_authors:
+
+Authors
+-------
+
+MySQL AB
+
+.. _myisam_version:
+
+Version
+-------
+
+This documentation applies to **myisam 2.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='myisam'
+

=== modified file 'plugin/mysql_protocol/docs/index.rst'
--- plugin/mysql_protocol/docs/index.rst	2011-03-01 12:37:54 +0000
+++ plugin/mysql_protocol/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -1,47 +1,203 @@
 MySQL Protocol
 ==============
 
-The MySQL Protocol plugin allows MySQL compatible clients to connect to Drizzle.
+MySQL Protocol Module.
+
+.. _mysql_protocol_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`mysql_protocol_configuration` and
+:ref:`mysql_protocol_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=mysql_protocol
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _mysql_protocol_configuration:
 
 Configuration
 -------------
 
-There are several server variables to control the MySQL Protocol.
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
 
 .. program:: drizzled
 
-.. option:: --mysql-protocol.port arg (=3306)
-
-   The port number to use with MySQL connections (0 is the same as 3306)
-
-.. option:: --mysql-protocol.connect-timeout arg (=10)
-
-   Connection timeout in seconds
-
-.. option:: --mysql-protocol.read-timeout arg (=30)
-
-   Port read timeout in seconds
-
-.. option:: --mysql-protocol.write-timeout arg (=60)
-
-   Port write timeout in seconds
-
-.. option:: --mysql-protocol.retry-count arg (=10)
-
-   Retry count for the read and write timeout before killing the connection
-
-.. option:: --mysql-protocol.buffer-length arg (=16384)
-
-   Buffer length
-
-.. option:: --mysql-protocol.bind-address arg
-
-   Address to bind to
-
-.. option:: --mysql-protocol.max-connections arg (=1000)
-
-   Maximum simultaneous connections
-
-.. option:: --mysql-protocol.admin-ip-addresses arg
-
-   A comma seprated list of IP addresses for admin tools to connect from
+.. option:: --mysql-protocol.bind-address ARG
+
+   :Default: localhost
+   :Variable: :ref:`mysql_protocol_bind_address <mysql_protocol_bind_address>`
+
+   Address to bind to.
+
+.. option:: --mysql-protocol.buffer-length ARG
+
+   :Default: 16384
+   :Variable: :ref:`mysql_protocol_buffer_length <mysql_protocol_buffer_length>`
+
+   Buffer length.
+
+.. option:: --mysql-protocol.connect-timeout ARG
+
+   :Default: 10
+   :Variable: :ref:`mysql_protocol_connect_timeout <mysql_protocol_connect_timeout>`
+
+   Connect Timeout.
+
+.. option:: --mysql-protocol.max-connections ARG
+
+   :Default: 1000
+   :Variable: :ref:`mysql_protocol_max_connections <mysql_protocol_max_connections>`
+
+   Maximum simultaneous connections.
+
+.. option:: --mysql-protocol.port ARG
+
+   :Default: 3306
+   :Variable: :ref:`mysql_protocol_port <mysql_protocol_port>`
+
+   Port number to use for connection or 0 for default to with MySQL 
+
+.. option:: --mysql-protocol.read-timeout ARG
+
+   :Default: 30
+   :Variable: :ref:`mysql_protocol_read_timeout <mysql_protocol_read_timeout>`
+
+   Read Timeout.
+
+.. option:: --mysql-protocol.retry-count ARG
+
+   :Default: 10
+   :Variable: :ref:`mysql_protocol_retry_count <mysql_protocol_retry_count>`
+
+   Retry Count.
+
+.. option:: --mysql-protocol.write-timeout ARG
+
+   :Default: 60
+   :Variable: :ref:`mysql_protocol_write_timeout <mysql_protocol_write_timeout>`
+
+   Write Timeout.
+
+.. _mysql_protocol_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _mysql_protocol_bind_address:
+
+* ``mysql_protocol_bind_address``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--mysql-protocol.bind-address`
+
+   Address to bind to.
+
+.. _mysql_protocol_buffer_length:
+
+* ``mysql_protocol_buffer_length``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--mysql-protocol.buffer-length`
+
+   Buffer length.
+
+.. _mysql_protocol_connect_timeout:
+
+* ``mysql_protocol_connect_timeout``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--mysql-protocol.connect-timeout`
+
+   Connect Timeout.
+
+.. _mysql_protocol_max_connections:
+
+* ``mysql_protocol_max_connections``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--mysql-protocol.max-connections`
+
+   Maximum simultaneous connections.
+
+.. _mysql_protocol_port:
+
+* ``mysql_protocol_port``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--mysql-protocol.port`
+
+   Port number to use for connection or 0 for default to with MySQL 
+
+.. _mysql_protocol_read_timeout:
+
+* ``mysql_protocol_read_timeout``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--mysql-protocol.read-timeout`
+
+   Read Timeout.
+
+.. _mysql_protocol_retry_count:
+
+* ``mysql_protocol_retry_count``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--mysql-protocol.retry-count`
+
+   Retry Count.
+
+.. _mysql_protocol_write_timeout:
+
+* ``mysql_protocol_write_timeout``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--mysql-protocol.write-timeout`
+
+   Write Timeout.
+
+.. _mysql_protocol_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _mysql_protocol_authors:
+
+Authors
+-------
+
+Eric Day
+
+.. _mysql_protocol_version:
+
+Version
+-------
+
+This documentation applies to **mysql_protocol 0.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='mysql_protocol'
+

=== modified file 'plugin/mysql_protocol/plugin.ini'
--- plugin/mysql_protocol/plugin.ini	2011-03-22 18:39:54 +0000
+++ plugin/mysql_protocol/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=MySQL Protocol Module
+title=MySQL Protocol
 description=MySQL protocol module that is based on the old libmysql code.
 load_by_default=yes
 ldlfags=$(LIBZ)

=== modified file 'plugin/mysql_unix_socket_protocol/docs/index.rst'
--- plugin/mysql_unix_socket_protocol/docs/index.rst	2011-03-05 09:09:04 +0000
+++ plugin/mysql_unix_socket_protocol/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -1,24 +1,118 @@
 MySQL Unix Socket Protocol
 ==========================
 
-The MySQL Unix Socket Protocol plugin allows MySQL compatible clients which
-use the unix socket file to connect to Drizzle.
+MySQL Unix Socket Protocol Module.
+
+.. _mysql_unix_socket_protocol_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`mysql_unix_socket_protocol_configuration` and
+:ref:`mysql_unix_socket_protocol_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=mysql_unix_socket_protocol
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _mysql_unix_socket_protocol_configuration:
 
 Configuration
 -------------
 
-There are several server variables to control the MySQL Unix Socket Protocol.
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
 
 .. program:: drizzled
 
-.. option:: --mysql-unix-socket-protocol.path (=/tmp/mysql.socket)
-
-   The path used for the socket file
-
-.. option:: --mysql-unix-socket-protocol.clobber
-
-   Remove the socket file if one already exists
-
-.. option:: --mysql-unix-socket-protocol.max-connections (=1000)
-
-   The maximum simultaneous connections via. the unix socket protocol
+.. option:: --mysql-unix-socket-protocol.clobber 
+
+   :Default: 
+   :Variable:
+
+   Clobber socket file if one is there already.
+
+.. option:: --mysql-unix-socket-protocol.max-connections ARG
+
+   :Default: 1000
+   :Variable: :ref:`mysql_unix_socket_protocol_max_connections <mysql_unix_socket_protocol_max_connections>`
+
+   Maximum simultaneous connections.
+
+.. option:: --mysql-unix-socket-protocol.path ARG
+
+   :Default: DRIZZLE_UNIX_SOCKET_PATH
+   :Variable:
+
+   Path used for MySQL UNIX Socket Protocol.
+
+.. _mysql_unix_socket_protocol_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _mysql_unix_socket_protocol_clobber:
+
+* ``mysql_unix_socket_protocol_clobber``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option:
+
+   Unknown
+
+.. _mysql_unix_socket_protocol_max_connections:
+
+* ``mysql_unix_socket_protocol_max_connections``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--mysql-unix-socket-protocol.max-connections`
+
+   Maximum simultaneous connections.
+
+.. _mysql_unix_socket_protocol_path:
+
+* ``mysql_unix_socket_protocol_path``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option:
+
+   Unknown
+
+.. _mysql_unix_socket_protocol_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _mysql_unix_socket_protocol_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _mysql_unix_socket_protocol_version:
+
+Version
+-------
+
+This documentation applies to **mysql_unix_socket_protocol 0.3**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='mysql_unix_socket_protocol'
+

=== modified file 'plugin/mysql_unix_socket_protocol/plugin.ini'
--- plugin/mysql_unix_socket_protocol/plugin.ini	2010-10-28 14:56:34 +0000
+++ plugin/mysql_unix_socket_protocol/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=MySQL Unix Socket Protocol Module
+title=MySQL Unix Socket Protocol
 description=MySQL Unix Socket Protocol Module
 version=0.3
 author=Brian Aker

=== added directory 'plugin/pbms/docs'
=== added file 'plugin/pbms/docs/index.rst'
--- plugin/pbms/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/pbms/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,65 @@
+PrimeBase Media Stream Daemon
+=============================
+
+PrimeBase Technologies GmbH.
+
+.. _pbms_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=pbms
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`pbms_configuration` and :ref:`pbms_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _pbms_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _pbms_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _pbms_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _pbms_authors:
+
+Authors
+-------
+
+Barry Leslie
+
+.. _pbms_version:
+
+Version
+-------
+
+This documentation applies to **pbms 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='pbms'
+

=== added directory 'plugin/performance_dictionary/docs'
=== added file 'plugin/performance_dictionary/docs/index.rst'
--- plugin/performance_dictionary/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/performance_dictionary/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,65 @@
+Performance Dictionary
+======================
+
+Data Dictionary for performance related table functions.
+
+.. _performance_dictionary_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=performance_dictionary
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`performance_dictionary_configuration` and :ref:`performance_dictionary_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _performance_dictionary_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _performance_dictionary_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _performance_dictionary_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _performance_dictionary_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _performance_dictionary_version:
+
+Version
+-------
+
+This documentation applies to **performance_dictionary 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='performance_dictionary'
+

=== added directory 'plugin/protocol_dictionary/docs'
=== added file 'plugin/protocol_dictionary/docs/index.rst'
--- plugin/protocol_dictionary/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/protocol_dictionary/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,67 @@
+Protocol Dictionary
+===================
+
+Provides dictionary for protocol counters.
+
+.. _protocol_dictionary_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`protocol_dictionary_configuration` and
+:ref:`protocol_dictionary_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=protocol_dictionary
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _protocol_dictionary_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _protocol_dictionary_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _protocol_dictionary_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _protocol_dictionary_authors:
+
+Authors
+-------
+
+Andrew Hutchings
+
+.. _protocol_dictionary_version:
+
+Version
+-------
+
+This documentation applies to **protocol_dictionary 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='protocol_dictionary'
+

=== modified file 'plugin/query_log/docs/index.rst'
--- plugin/query_log/docs/index.rst	2011-05-15 18:26:33 +0000
+++ plugin/query_log/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -12,8 +12,8 @@
 
 .. option:: --query-log.file FILE
 
-  | Default: :file:`drizzled-queries.log`
-  | Variable: ``query_log_file``
+  :Default: :file:`drizzled-queries.log`
+  :Variable: ``query_log_file``
 
   The query log file.  The file is created if it does not exist.  If a full
   path is not specified, the default relative path is the :file:`local`
@@ -21,8 +21,8 @@
 
 .. option:: --query-log.file-enabled
 
-  | Default: ``FALSE``
-  | Variable: ``query_log_file_enabled``
+  :Default: ``FALSE``
+  :Variable: ``query_log_file_enabled``
 
   Enable logging to :option:`--query-log.file`.
   This logging destination is disabled by default.  Specify this option to
@@ -31,8 +31,8 @@
 
 .. option:: --query-log.threshold-execution-time MICROSECONDS
 
-  | Default: ``0``
-  | Variable: ``query_log_threshold_execution_time``
+  :Default: ``0``
+  :Variable: ``query_log_threshold_execution_time``
 
   Log queries with execution times greater than ``MICROSECONDS``.
   The query log file writes ``execution_time`` as seconds with six decimal
@@ -41,8 +41,8 @@
 
 .. option:: --query-log.threshold-lock-time MICROSECONDS
 
-  | Default: ``0``
-  | Variable: ``query_log_threshold_lock_time``
+  :Default: ``0``
+  :Variable: ``query_log_threshold_lock_time``
 
   Log queries with lock times greater than ``MICROSECONDS``.
   The query log file writes ``lock_time`` as seconds with six decimal
@@ -51,22 +51,22 @@
 
 .. option:: --query-log.threshold-rows-examined N
 
-  | Default: ``0``
-  | Variable: ``query_log_threshold_rows_examined``
+  :Default: ``0``
+  :Variable: ``query_log_threshold_rows_examined``
 
   Log queries that examine more than ``N`` rows.
 
 .. option:: --query-log.threshold-rows-sent N
 
-  | Default: ``0``
-  | Variable: ``query_log_threshold_rows_sent``
+  :Default: ``0``
+  :Variable: ``query_log_threshold_rows_sent``
 
   Log queries that send (return) more than ``N`` rows.
 
 .. option:: --query-log.threshold-session-time MICROSECONDS
 
-  | Default: ``0``
-  | Variable: ``query_log_threshold_session_time``
+  :Default: ``0``
+  :Variable: ``query_log_threshold_session_time``
 
   Log queries form sessions active longer than ``MICROSECONDS``.
   The query log file writes ``session_time`` as seconds with six decimal
@@ -75,15 +75,15 @@
 
 .. option:: --query-log.threshold-tmp-tables N
 
-  | Default: ``0``
-  | Variable: ``query_log_threshold_tmp_tables``
+  :Default: ``0``
+  :Variable: ``query_log_threshold_tmp_tables``
 
   Log queries that use more than ``N`` temporary tables.
 
 .. option:: --query-log.threshold-warnings N
 
-  | Default: ``0``
-  | Variable: ``query_log_threshold_warnings``
+  :Default: ``0``
+  :Variable: ``query_log_threshold_warnings``
 
   Log queries that cause more than ``N`` errors.
 
@@ -179,3 +179,26 @@
   0.5 second *  1000000 = 500000 microseconds
 
 To convert back, multiple the number of microseconds by ``0.000001`` (that's zero point five zeros and a one).
+
+Authors
+-------
+
+Daniel Nichter
+
+Version
+-------
+
+This documentation applies to **query_log 0.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='query_log'
+
+Changelog
+---------
+
+v0.1
+^^^^
+* First release.

=== modified file 'plugin/rabbitmq/docs/index.rst'
--- plugin/rabbitmq/docs/index.rst	2011-04-01 19:31:01 +0000
+++ plugin/rabbitmq/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -3,68 +3,233 @@
 
 It is possible to replicate transactions directly to a `RabbitMQ <http://www.rabbitmq.org>`_ server from drizzle, this could be used to create advanced replication solutions, to visualize data, or to build triggers. For example, `RabbitReplication <http://www.rabbitreplication.org>`_ has been built to consume the messages from rabbitmq, transform them, and persist the data in drizzle, mysql, many nosql stores and even replicating directly to websockets for data visualization.
 
-Getting started
------------------------
-First install a recent version of RabbitMQ, then install librabbitmq, this is the c library for talking to the RabbitMQ server:
-
-.. code-block:: bash
-
-         $ hg clone http://hg.rabbitmq.com/rabbitmq-codegen/
-	 $ hg clone http://hg.rabbitmq.com/rabbitmq-c/
-	 $ cd rabbitmq-c
-	 $ autoreconf -f -i
-	 $ ./configure
-	 $ make
-	 $ make install
-
-Now you probably need to rebuild drizzle (the rabbitmq plugin is not built if librabbitmq is not installed), see :ref:`dependencies`.
-
-To start drizzled you need to add the replication plugins, start drizzled7 something like this (you probably want to add datadir etc as well, but these are the minimum):
-
-.. code-block:: bash
-
-         $ sbin/drizzled7 --plugin-add rabbitmq,default-replicator --rabbitmq.use-replicator default
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=rabbitmq
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`rabbitmq_configuration` and :ref:`rabbitmq_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _rabbitmq_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. option:: --rabbitmq.exchange ARG
+
+   :Default: ReplicationExchange
+   :Variable: :ref:`rabbitmq_exchange <rabbitmq_exchange>`
+
+   Name of RabbitMQ exchange to publish to
+
+.. option:: --rabbitmq.host ARG
+
+   :Default: localhost
+   :Variable: :ref:`rabbitmq_host <rabbitmq_host>`
+
+   Host name to connect to
+
+.. option:: --rabbitmq.password ARG
+
+   :Default: guest
+   :Variable: :ref:`rabbitmq_password <rabbitmq_password>`
+
+   RabbitMQ password
+
+.. option:: --rabbitmq.port ARG
+
+   :Default: 5672
+   :Variable: :ref:`rabbitmq_port <rabbitmq_port>`
+
+   Port to connect to
+
+.. option:: --rabbitmq.routingkey ARG
+
+   :Default: ReplicationRoutingKey
+   :Variable: :ref:`rabbitmq_routingkey <rabbitmq_routingkey>`
+
+   Name of RabbitMQ routing key to use
+
+.. option:: --rabbitmq.use-replicator ARG
+
+   :Default: default_replicator
+   :Variable:
+
+   Name of the replicator plugin to use (default='default_replicator')
+
+.. option:: --rabbitmq.username ARG
+
+   :Default: guest
+   :Variable: :ref:`rabbitmq_username <rabbitmq_username>`
+
+   RabbitMQ username
+
+.. option:: --rabbitmq.virtualhost ARG
+
+   :Default: /
+   :Variable: :ref:`rabbitmq_virtualhost <rabbitmq_virtualhost>`
+
+   RabbitMQ virtualhost
+
+.. _rabbitmq_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _rabbitmq_exchange:
+
+* ``rabbitmq_exchange``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--rabbitmq.exchange`
+
+   Name of RabbitMQ exchange to publish to
+
+.. _rabbitmq_host:
+
+* ``rabbitmq_host``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--rabbitmq.host`
+
+   Host name to connect to
+
+.. _rabbitmq_password:
+
+* ``rabbitmq_password``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--rabbitmq.password`
+
+   RabbitMQ password
+
+.. _rabbitmq_port:
+
+* ``rabbitmq_port``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--rabbitmq.port`
+
+   Port to connect to
+
+.. _rabbitmq_routingkey:
+
+* ``rabbitmq_routingkey``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--rabbitmq.routingkey`
+
+   Name of RabbitMQ routing key to use
+
+.. _rabbitmq_username:
+
+* ``rabbitmq_username``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--rabbitmq.username`
+
+   RabbitMQ username
+
+.. _rabbitmq_virtualhost:
+
+* ``rabbitmq_virtualhost``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--rabbitmq.virtualhost`
+
+   RabbitMQ virtualhost
+
+.. _rabbitmq_examples:
+
+Examples
+--------
+
+First install a recent version of RabbitMQ, then install librabbitmq, the C library for talking to the RabbitMQ server:
+
+.. code-block:: bash
+
+   $ hg clone http://hg.rabbitmq.com/rabbitmq-codegen/
+   $ hg clone http://hg.rabbitmq.com/rabbitmq-c/
+   $ cd rabbitmq-c
+   $ autoreconf -f -i
+   $ ./configure
+   $ make
+   $ make install
+
+Now you probably need to rebuild Drizzle since the :program:`rabbitmq` plugin is not built if librabbitmq is not installed.
+
+Finally, start :program:`drizzled` like:
+
+.. code-block:: bash
+
+   sbin/drizzled --plugin-add rabbitmq,default-replicator \
+                 --rabbitmq.use-replicator default
 
 To verify that it works, you can start a generic rabbitmq listener from librabbitmq:
 
 .. code-block:: bash
 
-         $ ./amqp_listen localhost 5672 ReplicationExchange ReplicationRoutingKey
-
-And you should see something like this when you do an INSERT/CREATE/.. (just not a select) in your newly built drizzle instance:
-
-.. code-block:: bash
-      
-     Result 0
-     Frame type 1, channel 1
-     Method AMQP_BASIC_DELIVER_METHOD
-     Delivery 1, exchange ReplicationExchange routingkey ReplicationRoutingKey
-
-     00000000: 0A 17 08 01 10 87 36 18 : F0 FA D9 99 FA F1 A7 02  ......6.........
-     00000010: 20 99 81 DA 99 FA F1 A7 : 02 12 40 08 01 10 F2 FA   .........@.....
-     00000020: D9 99 FA F1 A7 02 18 FC : FA D9 99 FA F1 A7 02 2A  ...............*
-     00000030: 17 0A 06 0A 01 62 12 01 : 61 12 06 08 04 12 02 69  .....b..a......i
-     00000040: 64 12 05 08 01 12 01 74 : 32 11 08 01 10 01 1A 0B  d......t2.......
-     00000050: 0A 01 32 0A 02 61 61 10 : 00 10 00 20 01 28 01     ..2..aa.... .(.
-     0000005F:
-
-It is possible to configure what `exchange <http://www.rabbitmq.com/faq.html#managing-concepts-exchanges>`_ and various other settings, these are the available config parameters:
-
-.. code-block:: bash
-
-   --rabbitmq.host arg (=localhost)                    Host name to connect to
-   --rabbitmq.port arg (=5672)                         Port to connect to
-   --rabbitmq.virtualhost arg (=/)                     RabbitMQ virtualhost
-   --rabbitmq.username arg (=guest)                    RabbitMQ username
-   --rabbitmq.password arg (=guest)                    RabbitMQ password
-   --rabbitmq.use-replicator arg (=default_replicator) Name of the replicator 
-   --rabbitmq.exchange arg (=ReplicationExchange)      Name of RabbitMQ exchange
-   --rabbitmq.routingkey arg (=ReplicationRoutingKey)  Name of RabbitMQ routing 
-   
-
-Implementation details
------------------------
-
-* If the rabbitmq server is not available when starting drizzled, drizzled will not start
-* If the rabbitmq server goes away, the plugin will try to reconnect and resend the message 3 times, after that, the transaction is rolled back
+   $ amqp_listen localhost 5672 ReplicationExchange ReplicationRoutingKey
+
+And you should see something like this when you do an INSERT/CREATE/.. (just not a select) in your newly built Drizzle instance::
+
+   Result 0
+   Frame type 1, channel 1
+   Method AMQP_BASIC_DELIVER_METHOD
+   Delivery 1, exchange ReplicationExchange routingkey ReplicationRoutingKey
+
+   00000000: 0A 17 08 01 10 87 36 18 : F0 FA D9 99 FA F1 A7 02  ......6.........
+   00000010: 20 99 81 DA 99 FA F1 A7 : 02 12 40 08 01 10 F2 FA   .........@.....
+   00000020: D9 99 FA F1 A7 02 18 FC : FA D9 99 FA F1 A7 02 2A  ...............*
+   00000030: 17 0A 06 0A 01 62 12 01 : 61 12 06 08 04 12 02 69  .....b..a......i
+   00000040: 64 12 05 08 01 12 01 74 : 32 11 08 01 10 01 1A 0B  d......t2.......
+   00000050: 0A 01 32 0A 02 61 61 10 : 00 10 00 20 01 28 01     ..2..aa.... .(.
+   0000005F:
+
+Implementation Details
+----------------------
+
+* :program:`drizzled` will not sart if the rabbitmq server is not available.
+* If the rabbitmq server goes away, the plugin will try to reconnect and resend the message 3 times, after that, the transaction is rolled back.
+
+.. _rabbitmq_authors:
+
+Authors
+-------
+
+Marcus Eriksson
+
+.. _rabbitmq_version:
+
+Version
+-------
+
+This documentation applies to **rabbitmq 0.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='rabbitmq'
 

=== modified file 'plugin/rabbitmq/plugin.ini'
--- plugin/rabbitmq/plugin.ini	2011-01-14 05:33:46 +0000
+++ plugin/rabbitmq/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,10 +1,9 @@
 [plugin]
-name=rabbitmq
+title=RabbitMQ Replicator
+description=Replicator plugin that publishes transactions to RabbitMQ
 version=0.1
 author=Marcus Eriksson
 license=PLUGIN_LICENSE_GPL
-title=RabbitMQ Replicator
-description=Replicator plugin that publishes transactions to RabbitMQ
 load_by_default=no
 sources=rabbitmq_log.cc rabbitmq_handler.cc
 headers=rabbitmq_log.h rabbitmq_handler.h

=== added directory 'plugin/rand_function/docs'
=== added file 'plugin/rand_function/docs/index.rst'
--- plugin/rand_function/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/rand_function/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,24 @@
+RAND Function
+=============
+
+The ``rand_function`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`rand-function`
+
+.. _rand_function_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=rand_function
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _rand_function_authors:
+
+Authors
+-------
+

=== modified file 'plugin/rand_function/plugin.ini'
--- plugin/rand_function/plugin.ini	2010-03-18 12:01:34 +0000
+++ plugin/rand_function/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,4 +1,4 @@
 [plugin]
-title=RAND() function
+title=RAND Function
 description=Function for pseudo-random number generation
 load_by_default=yes

=== added directory 'plugin/regex_policy/docs'
=== added file 'plugin/regex_policy/docs/index.rst'
--- plugin/regex_policy/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/regex_policy/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,82 @@
+Regex-based Authorization
+=========================
+
+Authorization plugin which implements a regex to object mapping.
+
+.. _regex_policy_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=regex_policy
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`regex_policy_configuration` and :ref:`regex_policy_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _regex_policy_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. option:: --regex-policy.policy ARG
+
+   :Default: DEFAULT_POLICY_FILE.string(
+   :Variable: :ref:`regex_policy_policy <regex_policy_policy>`
+
+   File to load for regex authorization policies
+
+.. _regex_policy_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _regex_policy_policy:
+
+* ``regex_policy_policy``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--regex-policy.policy`
+
+   File to load for regex authorization policies
+
+.. _regex_policy_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _regex_policy_authors:
+
+Authors
+-------
+
+Clint Byrum
+
+.. _regex_policy_version:
+
+Version
+-------
+
+This documentation applies to **regex_policy 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='regex_policy'
+

=== modified file 'plugin/regex_policy/plugin.ini'
--- plugin/regex_policy/plugin.ini	2011-03-03 01:55:10 +0000
+++ plugin/regex_policy/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=Regex Policy
+title=Regex-based Authorization
 description=Authorization plugin which implements a regex to object mapping
 version=1.0
 author=Clint Byrum <clint.byrum@canonical.com>

=== added directory 'plugin/registry_dictionary/docs'
=== added file 'plugin/registry_dictionary/docs/index.rst'
--- plugin/registry_dictionary/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/registry_dictionary/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,67 @@
+Registry Dictionary
+===================
+
+Provides dictionary for plugin registry system.
+
+.. _registry_dictionary_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`registry_dictionary_configuration` and
+:ref:`registry_dictionary_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=registry_dictionary
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _registry_dictionary_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _registry_dictionary_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _registry_dictionary_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _registry_dictionary_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _registry_dictionary_version:
+
+Version
+-------
+
+This documentation applies to **registry_dictionary 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='registry_dictionary'
+

=== added directory 'plugin/replication_dictionary/docs'
=== added file 'plugin/replication_dictionary/docs/index.rst'
--- plugin/replication_dictionary/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/replication_dictionary/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,59 @@
+Replication Dictionary
+======================
+
+Provides dictionary tables for replication system.
+
+.. _replication_dictionary_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`replication_dictionary_configuration` and
+:ref:`replication_dictionary_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=replication_dictionary
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _replication_dictionary_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _replication_dictionary_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _replication_dictionary_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _replication_dictionary_authors:
+
+Authors
+-------
+
+Jay Pipes
+
+.. _replication_dictionary_version:
+
+Version
+-------
+

=== modified file 'plugin/replication_dictionary/plugin.ini'
--- plugin/replication_dictionary/plugin.ini	2010-04-11 15:50:01 +0000
+++ plugin/replication_dictionary/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=Registry Dictionary
+title=Replication Dictionary
 author=Jay Pipes <jaypipes@gmail.com>
 license=PLUGIN_LICENSE_BSD
 description=Provides dictionary tables for replication system

=== added directory 'plugin/reverse_function/docs'
=== added file 'plugin/reverse_function/docs/index.rst'
--- plugin/reverse_function/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/reverse_function/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,39 @@
+REVERSE Function
+================
+
+The ``reverse_function`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`reverse-function`
+
+.. _reverse_function_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=reverse_function
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _reverse_function_authors:
+
+Authors
+-------
+
+Stewart Smith
+
+.. _reverse_function_version:
+
+Version
+-------
+
+This documentation applies to **reverse_function 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='reverse_function'
+

=== modified file 'plugin/reverse_function/plugin.ini'
--- plugin/reverse_function/plugin.ini	2010-02-15 02:27:14 +0000
+++ plugin/reverse_function/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,4 +1,4 @@
 [plugin]
-title=REVERSE function
+title=REVERSE Function
 description=function that reverses a string
 load_by_default=yes

=== added directory 'plugin/schema_dictionary/docs'
=== added file 'plugin/schema_dictionary/docs/index.rst'
--- plugin/schema_dictionary/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/schema_dictionary/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,67 @@
+Schema Dictionary
+=================
+
+Data Dictionary for schema.
+
+.. _schema_dictionary_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`schema_dictionary_configuration` and
+:ref:`schema_dictionary_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=schema_dictionary
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _schema_dictionary_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _schema_dictionary_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _schema_dictionary_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _schema_dictionary_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _schema_dictionary_version:
+
+Version
+-------
+
+This documentation applies to **schema_dictionary 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='schema_dictionary'
+

=== added directory 'plugin/schema_engine/docs'
=== added file 'plugin/schema_engine/docs/index.rst'
--- plugin/schema_engine/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/schema_engine/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,67 @@
+Schema Storage Engine
+=====================
+
+This implements the default file based Schema engine.
+
+.. _schema_engine_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`schema_engine_configuration` and
+:ref:`schema_engine_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=schema_engine
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _schema_engine_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _schema_engine_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _schema_engine_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _schema_engine_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _schema_engine_version:
+
+Version
+-------
+
+This documentation applies to **schema_engine 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='schema_engine'
+

=== modified file 'plugin/schema_engine/plugin.ini'
--- plugin/schema_engine/plugin.ini	2010-04-11 15:50:01 +0000
+++ plugin/schema_engine/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,6 +1,6 @@
 [plugin]
-title=Schema Engine
-description= This implements the default file based Schema engine.
+title=Schema Storage Engine
+description=This implements the default file based Schema engine.
 load_by_default=yes
 sources= 
   schema.cc

=== added directory 'plugin/session_dictionary/docs'
=== added file 'plugin/session_dictionary/docs/index.rst'
--- plugin/session_dictionary/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/session_dictionary/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,67 @@
+Session Dictionary
+==================
+
+Dictionary for session information.
+
+.. _session_dictionary_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`session_dictionary_configuration` and
+:ref:`session_dictionary_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=session_dictionary
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _session_dictionary_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _session_dictionary_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _session_dictionary_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _session_dictionary_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _session_dictionary_version:
+
+Version
+-------
+
+This documentation applies to **session_dictionary 1.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='session_dictionary'
+

=== added directory 'plugin/show_dictionary/docs'
=== added file 'plugin/show_dictionary/docs/index.rst'
--- plugin/show_dictionary/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/show_dictionary/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,67 @@
+SHOW Commands
+=============
+
+Dictionary for show commands.
+
+.. _show_dictionary_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`show_dictionary_configuration` and
+:ref:`show_dictionary_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=show_dictionary
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _show_dictionary_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _show_dictionary_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _show_dictionary_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _show_dictionary_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _show_dictionary_version:
+
+Version
+-------
+
+This documentation applies to **show_dictionary 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='show_dictionary'
+

=== modified file 'plugin/show_dictionary/plugin.ini'
--- plugin/show_dictionary/plugin.ini	2010-10-24 01:20:11 +0000
+++ plugin/show_dictionary/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=Show Dictionary
+title=SHOW Commands
 description= Creates dictionary tables for SHOW commands
 load_by_default=yes
 sources= 

=== added directory 'plugin/show_schema_proto/docs'
=== added file 'plugin/show_schema_proto/docs/index.rst'
--- plugin/show_schema_proto/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/show_schema_proto/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,39 @@
+SHOW_SCHEMA_PROTO Function
+==========================
+
+The ``show_schema_proto`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`show-schema-proto-function`
+
+.. _show_schema_proto_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=show_schema_proto
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _show_schema_proto_authors:
+
+Authors
+-------
+
+Stewart Smith
+
+.. _show_schema_proto_version:
+
+Version
+-------
+
+This documentation applies to **show_schema_proto 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='show_schema_proto'
+

=== modified file 'plugin/show_schema_proto/plugin.ini'
--- plugin/show_schema_proto/plugin.ini	2009-12-08 22:44:48 +0000
+++ plugin/show_schema_proto/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,6 +1,5 @@
 [plugin]
-name=show_schema_proto
-title=SHOW_SCHEMA_PROTO(db) Function
+title=SHOW_SCHEMA_PROTO Function
 description=Shows a text representation of the schema (database) proto
 load_by_default=yes
 cxxflags=${PROTOSKIP_WARNINGS}

=== added directory 'plugin/shutdown_function/docs'
=== added file 'plugin/shutdown_function/docs/index.rst'
--- plugin/shutdown_function/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/shutdown_function/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,38 @@
+SHUTDOWN Function
+=================
+
+The ``shutdown_function`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`shutdown-function`
+
+.. _shutdown_function_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=shutdown_function
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _shutdown_function_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _shutdown_function_version:
+
+Version
+-------
+
+This documentation applies to **shutdown_function 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='shutdown_function'
+

=== modified file 'plugin/shutdown_function/plugin.ini'
--- plugin/shutdown_function/plugin.ini	2010-08-18 20:27:50 +0000
+++ plugin/shutdown_function/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=Shutdown function
+title=SHUTDOWN Function
 description=Use this function to shutdown the database.
 load_by_default=no
 sources=shutdown.cc

=== added directory 'plugin/signal_handler/docs'
=== added file 'plugin/signal_handler/docs/index.rst'
--- plugin/signal_handler/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/signal_handler/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,67 @@
+Default Signal Handler
+======================
+
+Default Signal Handler.
+
+.. _signal_handler_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`signal_handler_configuration` and
+:ref:`signal_handler_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=signal_handler
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _signal_handler_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _signal_handler_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _signal_handler_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _signal_handler_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _signal_handler_version:
+
+Version
+-------
+
+This documentation applies to **signal_handler 0.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='signal_handler'
+

=== modified file 'plugin/signal_handler/plugin.ini'
--- plugin/signal_handler/plugin.ini	2009-11-10 20:47:10 +0000
+++ plugin/signal_handler/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,4 @@
 [plugin]
-name=signal_handler
 title=Default Signal Handler
 description=Default Signal Handler
 load_by_default=yes

=== added directory 'plugin/simple_user_policy/docs'
=== added file 'plugin/simple_user_policy/docs/index.rst'
--- plugin/simple_user_policy/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/simple_user_policy/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,65 @@
+User-based Authorization
+========================
+
+Authorization plugin which implements a simple policy-based strategy.
+
+.. _simple_user_policy_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=simple_user_policy
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`simple_user_policy_configuration` and :ref:`simple_user_policy_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _simple_user_policy_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _simple_user_policy_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _simple_user_policy_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _simple_user_policy_authors:
+
+Authors
+-------
+
+Monty Taylor
+
+.. _simple_user_policy_version:
+
+Version
+-------
+
+This documentation applies to **simple_user_policy 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='simple_user_policy'
+

=== modified file 'plugin/simple_user_policy/plugin.ini'
--- plugin/simple_user_policy/plugin.ini	2010-04-15 19:14:53 +0000
+++ plugin/simple_user_policy/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=Simple User Policy
+title=User-based Authorization
 description=Authorization plugin which implements a simple policy-based strategy
 version=1.0
 author=Monty Taylor <mordred@inaugust.com>

=== modified file 'plugin/slave/plugin.ini'
--- plugin/slave/plugin.ini	2011-03-31 22:51:58 +0000
+++ plugin/slave/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,7 +1,7 @@
 [plugin]
+title=Replication Slave
 version=1.0
 author=David Shrewsbury
-title=Replication Slave
 cxxflags=${LIBDRIZZLE_CPPFLAGS}
 description=Provides slave replication services
 sources=module.cc replication_slave.cc queue_thread.cc queue_consumer.cc queue_producer.cc sql_executor.cc replication_schema.cc

=== added directory 'plugin/sleep/docs'
=== added file 'plugin/sleep/docs/index.rst'
--- plugin/sleep/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/sleep/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,39 @@
+SLEEP Function
+==============
+
+The ``sleep`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`sleep-function`
+
+.. _sleep_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=sleep
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _sleep_authors:
+
+Authors
+-------
+
+Patrick Galbraith
+
+.. _sleep_version:
+
+Version
+-------
+
+This documentation applies to **sleep 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='sleep'
+

=== modified file 'plugin/sleep/plugin.ini'
--- plugin/sleep/plugin.ini	2011-02-22 22:57:45 +0000
+++ plugin/sleep/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,10 +1,9 @@
 [plugin]
-name=sleep
+title=SLEEP Function
+description=Function Plugin for sleep().
 version=1.0
 author=Patrick Galbraith
 license=PLUGIN_LICENSE_GPL
-title=Sleep Function
-description=Function Plugin for sleep().
 sources=sleep.cc
 static=yes
 load_by_default=yes

=== added directory 'plugin/status_dictionary/docs'
=== added file 'plugin/status_dictionary/docs/index.rst'
--- plugin/status_dictionary/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/status_dictionary/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,67 @@
+Status Dictionary
+=================
+
+Dictionary for status.
+
+.. _status_dictionary_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`status_dictionary_configuration` and
+:ref:`status_dictionary_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=status_dictionary
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _status_dictionary_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _status_dictionary_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _status_dictionary_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _status_dictionary_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _status_dictionary_version:
+
+Version
+-------
+
+This documentation applies to **status_dictionary 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='status_dictionary'
+

=== added directory 'plugin/string_functions/docs'
=== added file 'plugin/string_functions/docs/index.rst'
--- plugin/string_functions/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/string_functions/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,45 @@
+String Functions
+================
+
+The ``string_functions`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`elt-function`
+
+* :ref:`format-function`
+
+* :ref:`quote-function`
+
+* :ref:`regex-function`
+
+.. _string_functions_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=string_functions
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _string_functions_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _string_functions_version:
+
+Version
+-------
+
+This documentation applies to **string_functions 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='string_functions'
+

=== added directory 'plugin/substr_functions/docs'
=== added file 'plugin/substr_functions/docs/index.rst'
--- plugin/substr_functions/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/substr_functions/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,41 @@
+Substring Functions
+===================
+
+The ``substr_functions`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`substr-function`
+
+* :ref:`substring-index-function`
+
+.. _substr_functions_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=substr_functions
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _substr_functions_authors:
+
+Authors
+-------
+
+Stewart Smith
+
+.. _substr_functions_version:
+
+Version
+-------
+
+This documentation applies to **substr_functions 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='substr_functions'
+

=== modified file 'plugin/substr_functions/plugin.ini'
--- plugin/substr_functions/plugin.ini	2010-02-15 03:55:09 +0000
+++ plugin/substr_functions/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,4 +1,4 @@
 [plugin]
-title=SUBSTRING() and SUBSTRING_INDEX() functions
+title=Substring Functions
 description=SUBSTRING and SUBSTRING_INDEX functions
 load_by_default=yes

=== added directory 'plugin/syslog/docs'
=== added file 'plugin/syslog/docs/index.rst'
--- plugin/syslog/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/syslog/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,210 @@
+Syslog
+======
+
+Syslog interface for query log, error messages, and functions.
+
+.. _syslog_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`syslog_configuration` and
+:ref:`syslog_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=syslog
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _syslog_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. option:: --syslog.errmsg-enable 
+
+   :Default: false
+   :Variable: :ref:`syslog_errmsg_enable <syslog_errmsg_enable>`
+
+   Enable logging to syslog of the error messages
+
+.. option:: --syslog.errmsg-priority ARG
+
+   :Default: warning
+   :Variable: :ref:`syslog_errmsg_priority <syslog_errmsg_priority>`
+
+   Syslog Priority of error messages
+
+.. option:: --syslog.facility ARG
+
+   :Default: local0
+   :Variable: :ref:`syslog_facility <syslog_facility>`
+
+   Syslog Facility
+
+.. option:: --syslog.ident ARG
+
+   :Default: drizzled
+   :Variable:
+
+   Syslog Ident
+
+.. option:: --syslog.logging-enable 
+
+   :Default: false
+   :Variable: :ref:`syslog_logging_enable <syslog_logging_enable>`
+
+   Enable logging to syslog of the query log
+
+.. option:: --syslog.logging-priority ARG
+
+   :Default: warning
+   :Variable: :ref:`syslog_logging_priority <syslog_logging_priority>`
+
+   Syslog Priority of query logging
+
+.. option:: --syslog.logging-threshold-big-examined 
+
+   :Default: 0
+   :Variable: :ref:`syslog_logging_threshold_big_examined <syslog_logging_threshold_big_examined>`
+
+   Threshold for logging big queries
+
+.. option:: --syslog.logging-threshold-big-resultset 
+
+   :Default: 0
+   :Variable: :ref:`syslog_logging_threshold_big_resultset <syslog_logging_threshold_big_resultset>`
+
+   Threshold for logging big queries
+
+.. option:: --syslog.logging-threshold-slow 
+
+   :Default: 0
+   :Variable: :ref:`syslog_logging_threshold_slow <syslog_logging_threshold_slow>`
+
+   Threshold for logging slow queries
+
+.. _syslog_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _syslog_errmsg_enable:
+
+* ``syslog_errmsg_enable``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--syslog.errmsg-enable`
+
+   Enable logging to syslog of the error messages
+
+.. _syslog_errmsg_priority:
+
+* ``syslog_errmsg_priority``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--syslog.errmsg-priority`
+
+   Syslog Priority of error messages
+
+.. _syslog_facility:
+
+* ``syslog_facility``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--syslog.facility`
+
+   Syslog Facility
+
+.. _syslog_logging_enable:
+
+* ``syslog_logging_enable``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--syslog.logging-enable`
+
+   Enable logging to syslog of the query log
+
+.. _syslog_logging_priority:
+
+* ``syslog_logging_priority``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--syslog.logging-priority`
+
+   Syslog Priority of query logging
+
+.. _syslog_logging_threshold_big_examined:
+
+* ``syslog_logging_threshold_big_examined``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--syslog.logging-threshold-big-examined`
+
+   Threshold for logging big queries
+
+.. _syslog_logging_threshold_big_resultset:
+
+* ``syslog_logging_threshold_big_resultset``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--syslog.logging-threshold-big-resultset`
+
+   Threshold for logging big queries
+
+.. _syslog_logging_threshold_slow:
+
+* ``syslog_logging_threshold_slow``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--syslog.logging-threshold-slow`
+
+   Threshold for logging slow queries
+
+.. _syslog_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _syslog_authors:
+
+Authors
+-------
+
+Mark Atwood
+
+.. _syslog_version:
+
+Version
+-------
+
+This documentation applies to **syslog 0.3**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='syslog'
+

=== added directory 'plugin/table_cache_dictionary/docs'
=== added file 'plugin/table_cache_dictionary/docs/index.rst'
--- plugin/table_cache_dictionary/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/table_cache_dictionary/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,67 @@
+Table Cache Dictionary
+======================
+
+Data Dictionary for table and table definition cache.
+
+.. _table_cache_dictionary_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`table_cache_dictionary_configuration` and
+:ref:`table_cache_dictionary_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=table_cache_dictionary
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _table_cache_dictionary_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _table_cache_dictionary_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _table_cache_dictionary_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _table_cache_dictionary_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _table_cache_dictionary_version:
+
+Version
+-------
+
+This documentation applies to **table_cache_dictionary 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='table_cache_dictionary'
+

=== modified file 'plugin/table_cache_dictionary/plugin.ini'
--- plugin/table_cache_dictionary/plugin.ini	2010-04-11 15:50:01 +0000
+++ plugin/table_cache_dictionary/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,6 +1,6 @@
 [plugin]
-title=Table Cached and Table Definition Dictionary
-description= A look into the fabulous world of what is in your caches.
+title=Table Cache Dictionary
+description=A look into the fabulous world of what is in your caches.
 load_by_default=yes
 sources= 
   dictionary.cc

=== added directory 'plugin/tableprototester/docs'
=== added file 'plugin/tableprototester/docs/index.rst'
--- plugin/tableprototester/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/tableprototester/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,65 @@
+Table Proto Message Tester
+==========================
+
+Used to test rest of server with various table proto messages.
+
+.. _tableprototester_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=tableprototester
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`tableprototester_configuration` and :ref:`tableprototester_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _tableprototester_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _tableprototester_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _tableprototester_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _tableprototester_authors:
+
+Authors
+-------
+
+Stewart Smith
+
+.. _tableprototester_version:
+
+Version
+-------
+
+This documentation applies to **tableprototester 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='tableprototester'
+

=== modified file 'plugin/transaction_log/docs/index.rst'
--- plugin/transaction_log/docs/index.rst	2011-03-01 12:37:54 +0000
+++ plugin/transaction_log/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -1,48 +1,163 @@
 Transaction Log
 ===============
 
-Description
------------
-
 The Drizzle Transaction Log contains a sequence of
 `Google Protocol Buffer <http://code.google.com/p/protobuf/>`_
 messages that describe the transactions which have been run.
 
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`transaction_log_configuration` and
+:ref:`transaction_log_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=transaction_log
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _transaction_log_configuration:
 
 Configuration
 -------------
 
-Several server variables control the transaction log.
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
 
 .. program:: drizzled
 
 .. option:: --transaction-log.enable
 
+   :Default: false
+   :Variable: :ref:`transaction_log_enable <transaction_log_enable>`
+
    Enable transaction log.
 
-.. option:: --transaction-log.enable-checksum
+.. option:: --transaction-log.enable-checksum 
+
+   :Default: false
+   :Variable: :ref:`transaction_log_enable_checksum <transaction_log_enable_checksum>`
 
    Enable CRC32 Checksumming of each written transaction log entry
 
-.. option:: --transaction-log.file=arg
-
-  Path to the file to use for transaction log. The default will be
-  :file:`transaction.log`.
-
-.. option:: --transaction-log.use-replicator
-
-   Name of the replicator plugin to use (default='default_replicator')
+.. option:: --transaction-log.file ARG
+
+   :Default: :file:`transaction.log`
+   :Variable: :ref:`transaction_log_file <transaction_log_file>`
+
+   Path to the file to use for transaction log.
 
 .. option:: --transaction-log.flush-frequency=arg
 
+   :Default: ``0``
+   :Variable: :ref:`transaction_log_flush_frequency <transaction_log_flush_frequency>`
+
    * 0 : rely on operating system to sync log file (default)
    * 1 : sync file at each transaction write
    * 2 : sync log file once per second
 
-.. option:: --transaction-log.num-write-buffers=arg
+.. option:: --transaction-log.num-write-buffers ARG
+
+   :Default: 8
+   :Variable: :ref:`transaction_log_num_write_buffers <transaction_log_num_write_buffers>`
+
+   Number of slots for in-memory write buffers.
+
+.. option:: --transaction-log.truncate-debug 
+
+   :Default: false
+   :Variable: :ref:`transaction_log_truncate_debug <transaction_log_truncate_debug>`
+
+   DEBUGGING - Truncate transaction log.
+
+.. option:: --transaction-log.use-replicator ARG
+
+   :Default: ``default_replicator``
+   :Variable: :ref:`transaction_log_use_replicator <transaction_log_use_replicator>`
+
+   Name of the replicator plugin to use.
+
+.. _transaction_log_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _transaction_log_enable:
+
+* ``transaction_log_enable``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--transaction-log.enable`
+
+   If the transaction log is enabled or not.
+
+.. _transaction_log_enable_checksum:
+
+* ``transaction_log_enable_checksum``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--transaction-log.enable-checksum`
+
+   Enable CRC32 Checksumming of each written transaction log entry
+
+.. _transaction_log_file:
+
+* ``transaction_log_file``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--transaction-log.file`
+
+   Path to the file to use for transaction log
+
+.. _transaction_log_flush_frequency:
+
+* ``transaction_log_flush_frequency``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--transaction-log.flush-frequency`
+
+   Flush frequency.
+
+.. _transaction_log_num_write_buffers:
+
+* ``transaction_log_num_write_buffers``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--transaction-log.num-write-buffers`
 
    Number of slots for in-memory write buffers (default=8).
 
+.. _transaction_log_truncate_debug:
+
+* ``transaction_log_truncate_debug``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--transaction-log.truncate-debug`
+
+   DEBUGGING - Truncate transaction log
+
+.. _transaction_log_use_replicator:
+
+* ``transaction_log_use_replicator``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--transaction-log.use-replicator`
+
+   Name of the replicator plugin to use (default='default_replicator')
 
 Transaction Log Messages
 ------------------------
@@ -51,7 +166,6 @@
 <http://code.google.com/p/protobuf/>`_ (GPB) format. See the :doc:`Replication
 documentation </replication>` for more information.
 
-
 Transaction Log Format
 ----------------------
 
@@ -69,3 +183,37 @@
   this is always a Transaction GPB message.
 * **Length** - The length, in bytes, of the serialized message.
 * **Serialized Message** - The actual message data.
+
+.. _transaction_log_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _transaction_log_authors:
+
+Authors
+-------
+
+Jay Pipes
+
+.. _transaction_log_version:
+
+Version
+-------
+
+This documentation applies to **transaction_log 0.1.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='transaction_log'
+
+Changelog
+---------
+
+v0.1.1
+^^^^^^
+* First release.

=== modified file 'plugin/transaction_log/plugin.ini'
--- plugin/transaction_log/plugin.ini	2011-02-21 19:16:54 +0000
+++ plugin/transaction_log/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,10 +1,9 @@
 [plugin]
-name=transaction_log
+title=Transaction Log
+description=Log of Transaction Messages
 version=0.1.1
 author=Jay Pipes
 license=PLUGIN_LICENSE_GPL
-title=Transaction Log
-description=Log of Transaction Messages
 sources= hexdump_transaction_message.cc module.cc print_transaction_message.cc transaction_log.cc transaction_log_applier.cc transaction_log_entry.cc transaction_log_index.cc transaction_log_reader.cc data_dictionary_schema.cc write_buffer.cc
 headers= hexdump_transaction_message.h print_transaction_message.h transaction_log.h transaction_log_applier.h transaction_log_entry.h transaction_log_index.h transaction_log_reader.h data_dictionary_schema.h write_buffer.h
 libs=${top_builddir}/drizzled/algorithm/libhash.la 

=== added directory 'plugin/trigger_dictionary/docs'
=== added file 'plugin/trigger_dictionary/docs/index.rst'
--- plugin/trigger_dictionary/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/trigger_dictionary/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,65 @@
+Trigger Dictionary
+==================
+
+Table for describing what triggers have been loaded.
+
+.. _trigger_dictionary_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=trigger_dictionary
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`trigger_dictionary_configuration` and :ref:`trigger_dictionary_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _trigger_dictionary_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _trigger_dictionary_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _trigger_dictionary_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _trigger_dictionary_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _trigger_dictionary_version:
+
+Version
+-------
+
+This documentation applies to **trigger_dictionary 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='trigger_dictionary'
+

=== added directory 'plugin/user_locks/docs'
=== added file 'plugin/user_locks/docs/index.rst'
--- plugin/user_locks/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/user_locks/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,67 @@
+User Locks
+==========
+
+User level locking and barrier functions.
+
+.. _user_locks_loading:
+
+Loading
+-------
+
+This plugin is loaded by default, but it may need to be configured.  See
+the plugin's :ref:`user_locks_configuration` and
+:ref:`user_locks_variables`.
+
+To stop the plugin from loading by default, start :program:`drizzled`
+with::
+
+   --plugin-remove=user_locks
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _user_locks_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _user_locks_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _user_locks_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _user_locks_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _user_locks_version:
+
+Version
+-------
+
+This documentation applies to **user_locks 1.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='user_locks'
+

=== modified file 'plugin/user_locks/plugin.ini'
--- plugin/user_locks/plugin.ini	2010-11-27 06:34:30 +0000
+++ plugin/user_locks/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=User Locks.
+title=User Locks
 description=Provides lock functions to users.
 load_by_default=yes
 sources= 

=== added directory 'plugin/utility_dictionary/docs'
=== added file 'plugin/utility_dictionary/docs/index.rst'
--- plugin/utility_dictionary/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/utility_dictionary/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,65 @@
+Utility Dictionary
+==================
+
+Data Dictionary for utility tables.
+
+.. _utility_dictionary_loading:
+
+Loading
+-------
+
+To load this plugin, start :program:`drizzled` with::
+
+   --plugin-add=utility_dictionary
+
+Loading the plugin may not enable or configure it.  See the plugin's
+:ref:`utility_dictionary_configuration` and :ref:`utility_dictionary_variables`.
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _utility_dictionary_configuration:
+
+Configuration
+-------------
+
+These command line options configure the plugin when :program:`drizzled`
+is started.  See :doc:`/configuration` for more information about specifying
+command line options.
+
+.. program:: drizzled
+
+.. _utility_dictionary_variables:
+
+Variables
+---------
+
+These variables show the running configuration of the plugin.
+See `variables` for more information about querying and setting variables.
+
+.. _utility_dictionary_examples:
+
+Examples
+--------
+
+Sorry, there are no examples for this plugin.
+
+.. _utility_dictionary_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _utility_dictionary_version:
+
+Version
+-------
+
+This documentation applies to **utility_dictionary 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='utility_dictionary'
+

=== modified file 'plugin/utility_dictionary/plugin.ini'
--- plugin/utility_dictionary/plugin.ini	2010-09-30 03:36:05 +0000
+++ plugin/utility_dictionary/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,6 +1,6 @@
 [plugin]
-title=Utility data dictionary tables.
-description= Generate data to be used for tests, etc.
+title=Utility Dictionary
+description=Generate data to be used for tests, etc.
 load_by_default=no
 sources= 
   counter.cc

=== added directory 'plugin/utility_functions/docs'
=== added file 'plugin/utility_functions/docs/index.rst'
--- plugin/utility_functions/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/utility_functions/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,57 @@
+Utility Functions
+=================
+
+The ``utility_functions`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`assert-function`
+
+* :ref:`bit-count-function`
+
+* :ref:`catalog-function`
+
+* :ref:`execute-function`
+
+* :ref:`global-read-lock-function`
+
+* :ref:`result-type-function`
+
+* :ref:`kill-function`
+
+* :ref:`database-function`
+
+* :ref:`typeof-function`
+
+* :ref:`user-function`
+
+.. _utility_functions_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=utility_functions
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _utility_functions_authors:
+
+Authors
+-------
+
+Brian Aker
+
+.. _utility_functions_version:
+
+Version
+-------
+
+This documentation applies to **utility_functions 1.4**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='utility_functions'
+

=== added directory 'plugin/uuid_function/docs'
=== added file 'plugin/uuid_function/docs/index.rst'
--- plugin/uuid_function/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/uuid_function/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,39 @@
+UUID Function
+=============
+
+The ``uuid_function`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`uuid-function`
+
+.. _uuid_function_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=uuid_function
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _uuid_function_authors:
+
+Authors
+-------
+
+Stewart Smith
+
+.. _uuid_function_version:
+
+Version
+-------
+
+This documentation applies to **uuid_function 1.1**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='uuid_function'
+

=== modified file 'plugin/uuid_function/plugin.ini'
--- plugin/uuid_function/plugin.ini	2010-02-25 05:05:03 +0000
+++ plugin/uuid_function/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,5 +1,5 @@
 [plugin]
-title=UUID() plugin
+title=UUID Function
 description=UUID() function as generated by libuuid
 load_by_default=yes
 ldflags=${LTLIBUUID}

=== added directory 'plugin/version/docs'
=== added file 'plugin/version/docs/index.rst'
--- plugin/version/docs/index.rst	1970-01-01 00:00:00 +0000
+++ plugin/version/docs/index.rst	2011-08-13 20:41:38 +0000
@@ -0,0 +1,39 @@
+VERSION Function
+================
+
+The ``version`` plugin provides these :doc:`/functions/overview`:
+
+* :ref:`version-function`
+
+.. _version_loading:
+
+Loading
+-------
+
+This plugin is loaded by default.  To stop the plugin from loading by
+default, start :program:`drizzled` with::
+
+   --plugin-remove=version
+
+.. seealso:: :doc:`/options` for more information about adding and removing plugins.
+
+.. _version_authors:
+
+Authors
+-------
+
+Devananda van der Veen
+
+.. _version_version:
+
+Version
+-------
+
+This documentation applies to **version 1.0**.
+
+To see which version of the plugin a Drizzle server is running, execute:
+
+.. code-block:: mysql
+
+   SELECT MODULE_VERSION FROM DATA_DICTIONARY.MODULES WHERE MODULE_NAME='version'
+

=== modified file 'plugin/version/plugin.ini'
--- plugin/version/plugin.ini	2009-12-15 17:24:28 +0000
+++ plugin/version/plugin.ini	2011-08-13 20:41:38 +0000
@@ -1,9 +1,8 @@
 [plugin]
-name=version
+title=VERSION Function
 version=1.0
 author=Devananda van der Veen
 license=PLUGIN_LICENSE_GPL
-title=version UDF
 description=UDF Plugin for version function
 load_by_default=yes
 sources=versionudf.cc

